@@ -1,4 +1,4 @@
-//$Id: app-res.cc,v 1.6 2001/05/17 22:08:54 cactus Exp $ -*- c++ -*-
+//$Id: app-res.cc,v 1.8 2001/09/02 20:06:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,7 +22,10 @@
 using namespace Guikachu;
 
 Resources::Application::Application ():
-    gui (0)
+    gui (0),
+    iconname (changed, ""),
+    version (changed, ""),
+    vendor (changed, "")
 {
 }
 
@@ -93,9 +96,9 @@ bool Resources::Application::load (xmlDocPtr doc,
 
 void Resources::Application::save (xmlNodePtr node) const
 {
-    xmlNewChild (node, NULL, (xmlChar*)"iconname", (xmlChar*)iconname.c_str ());
-    xmlNewChild (node, NULL, (xmlChar*)"version",  (xmlChar*)version.c_str ());
-    xmlNewChild (node, NULL, (xmlChar*)"vendor",   (xmlChar*)vendor.c_str ());
+    xmlNewChild (node, NULL, (xmlChar*)"iconname", (xmlChar*)string (iconname).c_str ());
+    xmlNewChild (node, NULL, (xmlChar*)"version",  (xmlChar*)string (version).c_str ());
+    xmlNewChild (node, NULL, (xmlChar*)"vendor",   (xmlChar*)string (vendor).c_str ());
 }
 
 void Resources::Application::save_rcp (ostream &ostr) const
