@@ -1,4 +1,4 @@
-//$Id: app-res.h,v 1.3 2001/04/27 21:32:11 cactus Exp $ -*- c++ -*-
+//$Id: app-res.h,v 1.4 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -50,10 +50,10 @@ namespace Guikachu
 
 	    void show_ui ();
 
-	    GUIKACHU_RESOURCE_PROP(iconname, string);
-	    GUIKACHU_RESOURCE_PROP(version,  string);
-	    GUIKACHU_RESOURCE_PROP(vendor,   string);
-
+	    Property<string> iconname;
+	    Property<string> version;
+	    Property<string> vendor;
+	    
 	    void reset ();
 	    
 	private:
