@@ -1,4 +1,4 @@
-//$Id: app-win.cc,v 1.5 2001/08/10 16:10:34 cactus Exp $ -*- c++ -*-
+//$Id: app-win.cc,v 1.7 2001/08/31 16:11:37 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -47,29 +47,17 @@ GUI::AppWindow::AppWindow (Resources::Application *res_):
     Gtk::Entry *control;
     
     /* Icon caption */
-    control = new GUI::Entry (
-	false,
-	slot (res, &Resources::Application::get_iconname),
-	slot (res, &Resources::Application::set_iconname),
-	res->changed);
-    proptable->add (_("Icon caption:"), *manage (control));
+    control = new GUI::Entry (false, res->iconname);
+    proptable->add (_("Icon _caption:"), *manage (control));
 
     /* Version */
-    control = new GUI::Entry (
-	false,
-	slot (res, &Resources::Application::get_version),
-	slot (res, &Resources::Application::set_version),
-	res->changed);
-    proptable->add (_("Version:"), *manage (control));
+    control = new GUI::Entry (false, res->version);
+    proptable->add (_("_Version:"), *manage (control));
 
     /* Vendor ID */
-    control = new GUI::Entry (
-	false,
-	slot (res, &Resources::Application::get_vendor),
-	slot (res, &Resources::Application::set_vendor),
-	res->changed);
+    control = new GUI::Entry (false, res->vendor);
     control->set_max_length (4);
-    proptable->add (_("Vendor ID:"), *manage (control));
+    proptable->add (_("Vendor _ID:"), *manage (control));
 
     proptable->show_all ();
     window->add (*manage (proptable));
@@ -97,7 +85,7 @@ void GUI::AppWindow::show ()
 
 void GUI::AppWindow::update ()
 {
-    gchar *title_buf = g_strdup_printf (_("Application: %s"), res->get_iconname ().c_str ());
+    gchar *title_buf = g_strdup_printf (_("Application: %s"), res->iconname ().c_str ());
     window->set_title (title_buf);
     g_free (title_buf);
 }
