@@ -1,4 +1,4 @@
-//$Id: dialog-res.cc,v 1.9 2001/07/05 21:30:03 cactus Exp $ -*- c++ -*-
+//$Id: dialog-res.cc,v 1.12 2001/09/02 20:06:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,12 +22,16 @@
 
 using namespace Guikachu;
 
-Resources::Dialog::Dialog (const string& id_):
+Resources::Dialog::Dialog (const string& id):
+    Resource (id),
     gui (0),
-    dialog_type (DIALOG_INFORMATION)
+    title (changed, ""),
+    text (changed, ""),
+    dialog_type (changed, DIALOG_INFORMATION),
+    buttons (changed, vector<string>()),
+    default_button (changed, 0),
+    help_id (changed, "")
 {
-    id = id_;
-    default_button = 0;
 }
 
 Resources::Dialog::~Dialog ()
@@ -116,6 +120,7 @@ bool Resources::Dialog::load (xmlDocPtr doc,
 	    
 	    /* Iterate buttons */
 	    xmlNodePtr button_node;
+	    vector<string> button_vec;
 	    
 	    for (button_node = curr_node->xmlChildrenNode;
 		 button_node != NULL;
@@ -127,7 +132,7 @@ bool Resources::Dialog::load (xmlDocPtr doc,
 		    
 		    if (xml_val)
 		    {
-			buttons.push_back (xml_val);
+			button_vec.push_back (xml_val);
 			xmlFree (xml_val);
 		    }
 		} else {
@@ -136,6 +141,7 @@ bool Resources::Dialog::load (xmlDocPtr doc,
 			       curr_node->name, button_node->name);
 		}
 	    }
+	    buttons = button_vec;
 	}
 	    
 	else
@@ -171,35 +177,36 @@ void Resources::Dialog::save (xmlNodePtr node) const
     }
 
     my_node = xmlNewChild (node, NULL, (xmlChar*) "type", NULL);
-    xmlSetProp (my_node, (xmlChar*)"value", (xmlChar*)xml_type);    
+    xmlSetProp (my_node, (xmlChar*)"value", (xmlChar*)xml_type);
 
     /* Title */
     my_node = xmlNewChild (node, NULL, (xmlChar*) "title",
-			   (xmlChar*)title.c_str ());
+			   (xmlChar*)title ().c_str ());
     /* Text */
     my_node = xmlNewChild (node, NULL, (xmlChar*) "text",
-			   (xmlChar*)text.c_str ());
+			   (xmlChar*)text ().c_str ());
 
     /* Help ID */
     if (help_id != "")
     {
 	my_node = xmlNewChild (node, NULL, (xmlChar*) "help", NULL);
-	xmlSetProp (my_node, (xmlChar*) "id", (xmlChar*)help_id.c_str ());    
+	xmlSetProp (my_node, (xmlChar*) "id", (xmlChar*) help_id ().c_str ());    
     }
 
     /* Buttons */
-    if (buttons.size ())
+    vector<string> button_vec = buttons;
+    if (button_vec.size ())
     {
 	my_node = xmlNewChild (node, NULL, (xmlChar*) "buttons", NULL);
 
-	gchar *default_button_str = g_strdup_printf ("%d", default_button);
+	gchar *default_button_str = g_strdup_printf ("%d", default_button ());
 	xmlSetProp (my_node, (xmlChar*) "default", (xmlChar*) default_button_str);
 	g_free (default_button_str);
 	
 	xmlNodePtr button_node;
 
-	for (vector <string>::const_iterator i = buttons.begin ();
-	     i != buttons.end (); i++)
+	for (vector <string>::const_iterator i = button_vec.begin ();
+	     i != button_vec.end (); i++)
 	{
 	    button_node = xmlNewChild (my_node, NULL, (xmlChar*) "button", NULL);
 	    xmlSetProp (button_node, (xmlChar*) "label",
@@ -235,12 +242,13 @@ void Resources::Dialog::save_rcp (ostream &ostr) const
 
     ostr << "  TITLE \"" << title << "\"" << endl
 	 << "  MESSAGE \"" << text << "\"" << endl;
-    if (buttons.size ())
+    if (buttons ().size ())
     {
 	ostr << "  BUTTONS ";
 
-	for (vector <string>::const_iterator i = buttons.begin ();
-	     i !=  buttons.end (); i++)
+	vector<string> buttons_vec = buttons ();
+	for (vector <string>::const_iterator i = buttons_vec.begin ();
+	     i !=  buttons_vec.end (); i++)
 	    ostr << "\"" << *i << "\" ";
 	
 	ostr << endl;
