@@ -1,4 +1,4 @@
-//$Id: dialog-res.h,v 1.3 2001/03/11 14:14:37 cactus Exp $ -*- c++ -*-
+//$Id: dialog-res.h,v 1.4 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -49,18 +49,18 @@ namespace Guikachu
 	{
 	    Guikachu::GUI::DialogWindow *gui;
 	public:
-	    Dialog (const string& name);
+	    Dialog (const string& id);
 	    virtual ~Dialog ();
 	    
 	    virtual Type get_type () const { return RESOURCE_DIALOG; };
 	    virtual void show_ui ();
 
-	    GUIKACHU_RESOURCE_PROP(title,          string);
-	    GUIKACHU_RESOURCE_PROP(text,           string);
-	    GUIKACHU_RESOURCE_PROP(dialog_type,    DialogType);
-	    GUIKACHU_RESOURCE_PROP(buttons,        vector <string>);
-	    GUIKACHU_RESOURCE_PROP(default_button, unsigned int);
-	    GUIKACHU_RESOURCE_PROP(help_id,        string);
+	    Property<string>          title;
+	    Property<string>          text;
+	    Property<DialogType>      dialog_type;
+	    Property<vector<string> > buttons;
+	    Property<unsigned int>    default_button;
+	    Property<string>          help_id;
 	    
 	private:
 	    virtual bool load (xmlDocPtr xml_doc, xmlNodePtr node);
