@@ -1,4 +1,4 @@
-//$Id: button-canvas.cc,v 1.5 2001/07/24 01:48:19 cactus Exp $ -*- c++ -*-
+//$Id: button-canvas.cc,v 1.6 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -41,21 +41,11 @@ void ButtonCanvasItem::update ()
     group = new Gnome::CanvasGroup (*(form->get_canvas ()), 0, 0);
     set_canvas_item (group);
     
-    int width = widget->get_width ();
-    int height = widget->get_height ();
+    int width = widget->get_display_width ();
+    int height = widget->get_display_height ();
     int frame_width = 0;
     
-    int text_height, text_width;
-
-    text_width = get_string_width (widget->get_font (), widget->get_text ());
-    text_height = get_font_height (widget->get_font ());
-    
-    if (!widget->get_manual_width ())
-	width = 2 + text_width + 2;
-    if (!widget->get_manual_height ())
-	height = text_height + 3;
-
-    switch (widget->get_frame ())
+    switch (widget->frame)
     {
     case Widgets::BUTTON_FRAME_NONE:
 	frame_width = 0;
@@ -68,12 +58,12 @@ void ButtonCanvasItem::update ()
 	break;
     }
     
-    int x1 = widget->get_x ();
+    int x1 = widget->x;
     int x2 = x1 + width;
-    int y1 = widget->get_y ();
+    int y1 = widget->y;
     int y2 = y1 + height;
 
-    if (widget->get_frame () != Widgets::BUTTON_FRAME_NONE)
+    if (widget->frame != Widgets::BUTTON_FRAME_NONE)
     {
 	Gnome::CanvasPoints frame_points;
 	using namespace Gnome::Art;
@@ -95,7 +85,7 @@ void ButtonCanvasItem::update ()
 	Gnome::CanvasPolygon *button_frame = new Gnome::CanvasPolygon (*group, frame_points);
 	button_frame->set_width_units (frame_width);
 
-	if (widget->get_usable ())
+	if (widget->usable)
 	    button_frame->set_outline_color (GUIKACHU_FGC);
 	else
 	    button_frame->set_outline_color (GUIKACHU_FGC_DISABLED);
@@ -105,9 +95,9 @@ void ButtonCanvasItem::update ()
     int text_y = y1 + height / 2;
     
     draw_text (*group,
-	       widget->get_text (), widget->get_font (),
+	       widget->text, widget->font,
 	       text_x, text_y,
-	       widget->get_usable (),
+	       widget->usable,
 	       GTK_ANCHOR_CENTER,
 	       width, height);
 }
