@@ -1,4 +1,4 @@
-//$Id: button.cc,v 1.14 2001/04/30 20:47:26 cactus Exp $ -*- c++ -*-
+//$Id: button.cc,v 1.17 2001/09/02 20:12:57 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,30 +19,23 @@
 #include "button.h"
 #include "button-canvas.h"
 
+#include "form-editor.h"
+
 #include <gnome-xml/xmlmemory.h>
 
 using Guikachu::Widgets::Button;
 using namespace Guikachu::GUI::FormEditor;
 
-Button::Button (Resources::Form *owner_,
-		const string& id_):
-    text (id_),
-    font (0),
-    frame (BUTTON_FRAME_SIMPLE),
-    usable (true),
-    repeat (false),
-    anchor_right (false),
-    width (1),
-    manual_width (false),
-    height (1),
-    manual_height (false)
+Button::Button (Resources::Form *owner,
+		const string& id):
+    Widget (owner, id),
+    Resizeable (changed),
+    Textual (changed, id),
+    frame (changed, BUTTON_FRAME_SIMPLE),
+    usable (changed, true),
+    repeat (changed, false),
+    anchor_right (changed, false)
 {
-    id = id_;
-    owner = owner_;
-
-    x = 5;
-    y = 20;
-
     editor = new ButtonProperties (this);
 }
 
@@ -175,23 +168,23 @@ void Button::save (xmlNodePtr node) const
 
     /* Position */
     my_node = xmlNewChild (node, NULL, (xmlChar*) "pos", NULL);
-    buffer = g_strdup_printf ("%d", x);
+    buffer = g_strdup_printf ("%d", int (x));
     xmlSetProp (my_node, (xmlChar*) "x", (xmlChar*) buffer);
     g_free (buffer);
-    buffer = g_strdup_printf ("%d", y);
+    buffer = g_strdup_printf ("%d", int (y));
     xmlSetProp (my_node, (xmlChar*) "y", (xmlChar*) buffer);
     g_free (buffer);
 
     /* Size */
     if (manual_width)
-	buffer = g_strdup_printf ("%d", width);
+	buffer = g_strdup_printf ("%d", int (width));
     else
 	buffer = g_strdup ("auto");
     xmlSetProp (my_node, (xmlChar*) "width", (xmlChar*) buffer);
     g_free (buffer);
 
     if (manual_height)
-	buffer = g_strdup_printf ("%d", height);
+	buffer = g_strdup_printf ("%d", int (height));
     else
 	buffer = g_strdup ("auto");
     xmlSetProp (my_node, (xmlChar*) "height", (xmlChar*) buffer);
@@ -219,8 +212,8 @@ void Button::save (xmlNodePtr node) const
     
     /* Label and font */
     my_node = xmlNewChild (node, NULL, (xmlChar*) "text",
-			   (xmlChar*) text.c_str ());
-    buffer = g_strdup_printf ("%d", font);
+			   (xmlChar*) string (text).c_str ());
+    buffer = g_strdup_printf ("%d", int (font));
     xmlSetProp (my_node, (xmlChar*) "font", (xmlChar*) buffer);
     g_free (buffer);
 }
@@ -237,12 +230,12 @@ void Button::save_rcp (ostream &ostr) const
 	type_str = "REPEATBUTTON";
     
     if (manual_width)
-	width_str = g_strdup_printf ("%d", width);
+	width_str = g_strdup_printf ("%d", int (width));
     else
 	width_str = g_strdup ("AUTO");
     
     if (manual_height)
-	height_str = g_strdup_printf ("%d", height);
+	height_str = g_strdup_printf ("%d", int (height));
     else
 	height_str = g_strdup ("AUTO");
     
@@ -284,3 +277,21 @@ CanvasItem* Button::get_canvas_item (GUI::FormEditor::Form *form)
 {
     return new ButtonCanvasItem (this, form);
 }
+
+int Button::get_display_width ()
+{
+    if (manual_width)
+	return width;
+
+    int text_width = get_string_width (font, text);
+    return 2 + text_width + 2;
+}
+
+int Button::get_display_height ()
+{
+    if (manual_height)
+	return height;
+
+    int text_height = get_font_height (font);
+    return text_height + 3;
+}
