@@ -1,4 +1,4 @@
-//$Id: button.h,v 1.5 2001/04/22 13:03:11 cactus Exp $ -*- c++ -*-
+//$Id: button.h,v 1.7 2001/08/18 16:22:55 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -41,13 +41,18 @@ namespace Guikachu
     }
 }
 
+#include "resizeable.h"
+#include "textual.h"
+
 #include "button-prop.h"
 
 namespace Guikachu
 {
     namespace Widgets
     {
-	class Button: public Widget
+	class Button: public Widget,
+		      public Resizeable,
+		      public Textual
 	{
 	    GUI::FormEditor::ButtonProperties *editor;
 	    
@@ -60,19 +65,15 @@ namespace Guikachu
 	    
 	    virtual GUI::FormEditor::CanvasItem *get_canvas_item (GUI::FormEditor::Form *form);
 	    virtual Gtk::Widget *get_editor ();
-	    
-	    GUIKACHU_RESOURCE_PROP (text,          string);
-	    GUIKACHU_RESOURCE_PROP (font,          int);
-	    GUIKACHU_RESOURCE_PROP (frame,         ButtonFrameType);
 
-	    GUIKACHU_RESOURCE_PROP (usable,        bool);
-	    GUIKACHU_RESOURCE_PROP (repeat,        bool);
-	    GUIKACHU_RESOURCE_PROP (anchor_right,  bool);
+	    virtual int get_display_width ();
+	    virtual int get_display_height ();
 
-	    GUIKACHU_RESOURCE_PROP (width,         int);
-	    GUIKACHU_RESOURCE_PROP (manual_width,  bool);
-	    GUIKACHU_RESOURCE_PROP (height,        int);
-	    GUIKACHU_RESOURCE_PROP (manual_height, bool);
+	    Property<ButtonFrameType> frame;
+
+	    Property<bool>            usable;
+	    Property<bool>            repeat;
+	    Property<bool>            anchor_right;
 	    
 	private:
 	    // Persistance
