@@ -1,4 +1,4 @@
-//$Id: canvasitem.cc,v 1.4 2001/08/13 16:22:05 cactus Exp $ -*- c++ -*-
+//$Id: canvasitem.cc,v 1.5 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -169,15 +169,13 @@ void CanvasItem::drag_begin (GdkEvent *e)
     drag_context.last_x = e->button.x;
     drag_context.last_y = e->button.y;
     
-    drag_context.offset_x = drag_context.last_x - widget->get_x ();
-    drag_context.offset_y = drag_context.last_y - widget->get_y ();
+    drag_context.offset_x = drag_context.last_x - widget->x;
+    drag_context.offset_y = drag_context.last_y - widget->y;
     
     Gdk_Cursor cursor (gdk_cursor_new (GDK_FLEUR));
     item->grab (GDK_POINTER_MOTION_MASK | GDK_BUTTON_MOTION_MASK |
 		GDK_BUTTON_RELEASE_MASK | GDK_BUTTON_PRESS_MASK,
 		cursor, e->button.time);
-
-//    cout << e->button.x << "\t" << e->button.y << endl;
 }
 
 void CanvasItem::drag_motion (GdkEvent *e)
@@ -217,7 +215,7 @@ void CanvasItem::drag_end (GdkEvent *e)
     
     if (drag_context.drag_occured)
     {
-	widget->set_x ((int)(drag_context.last_x - drag_context.offset_x));
-	widget->set_y ((int)(drag_context.last_y - drag_context.offset_y));
+	widget->x = (int)(drag_context.last_x - drag_context.offset_x);
+	widget->y = (int)(drag_context.last_y - drag_context.offset_y);
     }
 }
