@@ -1,4 +1,4 @@
-//$Id: checkbox.cc,v 1.4 2001/05/09 16:07:04 cactus Exp $ -*- c++ -*-
+//$Id: checkbox.cc,v 1.7 2001/09/02 20:12:57 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,30 +19,23 @@
 #include "checkbox.h"
 #include "checkbox-canvas.h"
 
+#include "form-editor.h"
+
 #include <gnome-xml/xmlmemory.h>
 
 using Guikachu::Widgets::Checkbox;
 using namespace Guikachu::GUI::FormEditor;
 
-Checkbox::Checkbox (Resources::Form *owner_,
-				  const string& id_):
-    text (id_),
-    font (0),
-    usable (true),
-    group (0),
-    toggled (false),
-    anchor_right (false),
-    width (1),
-    manual_width (false),
-    height (1),
-    manual_height (false)
+Checkbox::Checkbox (Resources::Form *owner,
+		    const string& id):
+    Widget (owner, id),
+    Resizeable (changed),
+    Textual (changed, id),
+    usable (changed, true),
+    anchor_right (changed, false),
+    group (this),
+    toggled (this)
 {
-    id = id_;
-    owner = owner_;
-
-    x = 5;
-    y = 20;
-
     editor = new CheckboxProperties (this);
 }
 
@@ -51,24 +44,36 @@ Checkbox::~Checkbox ()
     delete editor;
 }
 
-void Checkbox::set_toggled (const bool& toggled_)
+Checkbox::GroupProp::GroupProp (Checkbox *owner_):
+    Property<int> (owner_->changed),
+    owner (owner_)
 {
-    if (toggled_ == toggled)
-	return;
+}
 
-    toggled = toggled_;
-    if (toggled && group)
+Checkbox::ToggledProp::ToggledProp (Checkbox *owner_):
+    Property<bool> (owner_->changed),
+    owner (owner_)
+{
+}
+
+void Checkbox::ToggledProp::set_val (const bool& value_)
+{
+    if (value_ == value)
+	return;
+    
+    value = value_;
+    if (value_ && owner->group)
     {
-	set<Widgets::Widget*> widgets = owner->get_widgets ();
+	set<Widgets::Widget*> widgets = owner->get_form ()->get_widgets ();
 	for (set<Widgets::Widget*>::iterator i = widgets.begin ();
 	     i != widgets.end (); i++)
 	{
 	    if ((*i)->get_type () == WIDGET_CHECKBOX &&
-		(*i) != this)
+		(*i) != owner)
 	    {
-		Checkbox *box = static_cast <Checkbox*> (*i);
-		if (box->get_group () == group && box->get_toggled ())
-		    box->set_toggled (false);
+		Checkbox *checkbox = static_cast <Checkbox*> (*i);
+		if (checkbox->group == owner->group && checkbox->toggled)
+		    checkbox->toggled = false;
 	    }
 	}
     }
@@ -76,16 +81,16 @@ void Checkbox::set_toggled (const bool& toggled_)
     changed ();
 }
 
-void Checkbox::set_group (const int& group_)
+void Checkbox::GroupProp::set_val (const int& value_)
 {   
-    if (group_ == group)
+    if (value_ == value)
 	return;
 
-    group = group_;
+    value = value_;
     
-    if (group)
+    if (value_)
     {
-	set<Widgets::Widget*> widgets = owner->get_widgets ();
+	set<Widgets::Widget*> widgets = owner->get_form ()->get_widgets ();
 	set<Widgets::Widget*>::iterator i = widgets.begin ();
 	bool found = false;
 
@@ -93,22 +98,19 @@ void Checkbox::set_group (const int& group_)
 	while (!found && i != widgets.end ())
 	{
 	    if ((*i)->get_type () == WIDGET_CHECKBOX &&
-		(*i) != this)
+		(*i) != owner)
 	    {
-		Checkbox *box = static_cast <Checkbox*> (*i);
-		if (box->get_group () == group && box->get_toggled ())
-		{
-		    cerr << box->get_id () << endl;
+		Checkbox *checkbox = static_cast <Checkbox*> (*i);
+		if (checkbox->group == owner->group && checkbox->toggled)
 		    found = true;
-		}
 	    }
 	    
 	    i++;
 	}
 
 	// If there is, untoggle ourselves
-	if (found && toggled)
-	    toggled = false;
+	if (found && owner->toggled)
+	    owner->toggled = false;
     }
     
     changed ();
@@ -135,11 +137,11 @@ bool Checkbox::load (xmlDocPtr doc,
     
 #define XML_HAS_NAME(node, val) (!strcmp ((char*) node->name, val))
     
-#define XML_APPLY(attr)       \
-	if (xml_val)          \
-	{                     \
-	    attr = xml_val;   \
-	    xmlFree (xml_val);\
+#define XML_APPLY(attr)						\
+	if (xml_val)						\
+	{							\
+	    attr = xml_val;					\
+	    xmlFree (xml_val);					\
 	}
 
 #define XML_GET_CONTENT(node, attr) \
@@ -237,23 +239,23 @@ void Checkbox::save (xmlNodePtr node) const
 
     /* Position */
     my_node = xmlNewChild (node, NULL, (xmlChar*) "pos", NULL);
-    buffer = g_strdup_printf ("%d", x);
+    buffer = g_strdup_printf ("%d", x ());
     xmlSetProp (my_node, (xmlChar*) "x", (xmlChar*) buffer);
     g_free (buffer);
-    buffer = g_strdup_printf ("%d", y);
+    buffer = g_strdup_printf ("%d", y ());
     xmlSetProp (my_node, (xmlChar*) "y", (xmlChar*) buffer);
     g_free (buffer);
 
     /* Frame */
     if (manual_width)
-	buffer = g_strdup_printf ("%d", width);
+	buffer = g_strdup_printf ("%d", width ());
     else
 	buffer = g_strdup ("auto");
     xmlSetProp (my_node, (xmlChar*) "width", (xmlChar*) buffer);
     g_free (buffer);
 
     if (manual_height)
-	buffer = g_strdup_printf ("%d", height);
+	buffer = g_strdup_printf ("%d", height ());
     else
 	buffer = g_strdup ("auto");
     xmlSetProp (my_node, (xmlChar*) "height", (xmlChar*) buffer);
@@ -265,7 +267,7 @@ void Checkbox::save (xmlNodePtr node) const
 
     /* Group ID */
     my_node = xmlNewChild (node, NULL, (xmlChar*) "group", NULL);
-    buffer = g_strdup_printf ("%d", group);
+    buffer = g_strdup_printf ("%d", group ());
     xmlSetProp (my_node, (xmlChar*) "id", (xmlChar*) buffer);
     g_free (buffer);
 
@@ -279,8 +281,8 @@ void Checkbox::save (xmlNodePtr node) const
     
     /* Label and font */
     my_node = xmlNewChild (node, NULL, (xmlChar*) "text",
-			   (xmlChar*) text.c_str ());
-    buffer = g_strdup_printf ("%d", font);
+			   (xmlChar*) string (text).c_str ());
+    buffer = g_strdup_printf ("%d", font ());
     xmlSetProp (my_node, (xmlChar*) "font", (xmlChar*) buffer);
     g_free (buffer);
 }
@@ -290,12 +292,12 @@ void Checkbox::save_rcp (ostream &ostr) const
     gchar *width_str, *height_str;
 
     if (manual_width)
-	width_str = g_strdup_printf ("%d", width);
+	width_str = g_strdup_printf ("%d", width ());
     else
 	width_str = g_strdup ("AUTO");
     
     if (manual_height)
-	height_str = g_strdup_printf ("%d", height);
+	height_str = g_strdup_printf ("%d", height ());
     else
 	height_str = g_strdup ("AUTO");
 
@@ -324,3 +326,22 @@ CanvasItem* Checkbox::get_canvas_item (GUI::FormEditor::Form *form)
 {
     return new CheckboxCanvasItem (this, form);
 }
+
+int Checkbox::get_display_width ()
+{
+    if (manual_width)
+	return width;
+
+    int text_width = get_string_width (font, text);
+    
+    return 18 + text_width;
+}
+
+int Checkbox::get_display_height ()
+{
+    if (manual_height)
+	return height;
+    
+    int text_height = get_font_height (font);
+    return text_height + 3;
+}
