@@ -1,4 +1,4 @@
-//$Id: checkbox.h,v 1.3 2001/05/09 16:07:04 cactus Exp $ -*- c++ -*-
+//$Id: checkbox.h,v 1.5 2001/08/18 16:22:55 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -34,15 +34,38 @@ namespace Guikachu
     }
 }
 
+#include "resizeable.h"
+#include "textual.h"
+
 #include "checkbox-prop.h"
 
 namespace Guikachu
 {
     namespace Widgets
     {
-	class Checkbox: public Widget
+	class Checkbox: public Widget,
+			public Resizeable,
+			public Textual
 	{
 	    GUI::FormEditor::CheckboxProperties *editor;
+
+	    class GroupProp: public Property<int>
+	    {
+		Checkbox *owner;
+	    public:
+		GroupProp (Checkbox *owner);
+		virtual void set_val (const int& value);
+		inline const int& operator= (const int& value_) { set_val (value_); return value; };
+	    };
+	    
+	    class ToggledProp: public Property<bool>
+	    {
+		Checkbox *owner;
+	    public:
+		ToggledProp (Checkbox *owner);
+		virtual void set_val (const bool& value);
+		inline const bool& operator= (const bool& value_) { set_val (value_); return value; };
+	    };
 	    
 	public:
 	    Checkbox (Resources::Form *owner,
@@ -53,19 +76,14 @@ namespace Guikachu
 	    
 	    virtual GUI::FormEditor::CanvasItem *get_canvas_item (GUI::FormEditor::Form *form);
 	    virtual Gtk::Widget *get_editor ();
-	    
-	    GUIKACHU_RESOURCE_PROP (text,            string);
-	    GUIKACHU_RESOURCE_PROP (font,            int);
 
-	    GUIKACHU_RESOURCE_PROP (usable,          bool);
-	    GUIKACHU_RESOURCE_PROP_CUSTSET (group,   int);
-	    GUIKACHU_RESOURCE_PROP_CUSTSET (toggled, bool);
-	    GUIKACHU_RESOURCE_PROP (anchor_right,    bool);
-	    
-	    GUIKACHU_RESOURCE_PROP (width,           int);
-	    GUIKACHU_RESOURCE_PROP (manual_width,    bool);
-	    GUIKACHU_RESOURCE_PROP (height,          int);
-	    GUIKACHU_RESOURCE_PROP (manual_height,   bool);
+	    virtual int get_display_width ();
+	    virtual int get_display_height ();
+
+	    Property<bool>   usable;
+	    Property<bool>   anchor_right;
+	    GroupProp        group;
+	    ToggledProp      toggled;
 	    
 	private:
 	    // Persistance
