@@ -1,4 +1,4 @@
-//$Id: form.cc,v 1.17 2001/08/13 16:22:05 cactus Exp $ -*- c++ -*-
+//$Id: form.cc,v 1.18 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -77,8 +77,8 @@ void Form::update ()
     draw_frame ();
     draw_title ();
     
-    group->set_x (res->get_x ());
-    group->set_y (res->get_y ());
+    group->set_x (res->x);
+    group->set_y (res->y);
 
     /* Reset canvas group */
     if (widget_group)
@@ -119,14 +119,14 @@ void Form::draw_frame ()
     Gnome::CanvasRect *frame_rect =
 	new Gnome::CanvasRect (*frame_group,
 			       -1, -1,
-			       res->get_width (), res->get_height ());
+			       res->width, res->height);
     frame_rect->set_width_units (1);
     frame_rect->set_fill_color ("");
     
-    if (res->get_modal ())
+    if (res->modal)
 	draw_frame_modal ();
     else
-	if (res->get_frame ())
+	if (res->frame)
 	    draw_frame_nonmodal ();
 }
 
@@ -135,7 +135,7 @@ void Form::draw_frame_nonmodal ()
     Gnome::CanvasRect *frame_rect =
 	new Gnome::CanvasRect (*frame_group,
 			       -1, -1,
-			       res->get_width (), res->get_height ());
+			       res->width, res->height);
     
     frame_rect->set_width_units (1);
     frame_rect->set_outline_color (GUIKACHU_FGC);
@@ -148,8 +148,8 @@ void Form::draw_frame_modal ()
 
     int x0 = 0;
     int y0 = 0;
-    int x1 = res->get_width ();
-    int y1 = res->get_height ();
+    int x1 = res->width;
+    int y1 = res->height;
     
     // NW
     outer_points.push_back (Gnome::Art::Point ( (x0 - 2), (y0)     ));
@@ -201,10 +201,10 @@ void Form::draw_title ()
 	delete title_group;
     title_group = new Gnome::CanvasGroup (*group, 0, 0);
 
-    if (res->get_title () == "")
+    if (res->title == "")
 	return;
     
-    if (res->get_modal ())
+    if (res->modal)
 	draw_title_modal ();
     else
 	draw_title_nonmodal ();
@@ -216,11 +216,11 @@ void Form::draw_title_nonmodal ()
     double title_width;
     Font &font = get_title_font ();
     
-    title_width = get_string_width (1, res->get_title ()) + 2; /* Title is font#1 */
-    title_width = MIN (title_width + 5, res->get_width ());
+    title_width = get_string_width (1, res->title) + 2; /* Title is font#1 (FIXME) */
+    title_width = MIN (title_width + 5, res->width);
 
-    int max_width = res->get_width ();
-    int max_height = MIN (res->get_height (), GUIKACHU_WINDOW_TITLE_HEIGHT);
+    int max_width = res->width;
+    int max_height = MIN (res->height, GUIKACHU_WINDOW_TITLE_HEIGHT);
     
     // NW corner
     points.push_back (Gnome::Art::Point (0, 1));
@@ -244,7 +244,7 @@ void Form::draw_title_nonmodal ()
 	    << width_units (1)
 	    << fill_color (GUIKACHU_FGC);
 
-	render_text (*title_group, res->get_title (), font,
+	render_text (*title_group, res->title, font,
 		     Gdk_Color (GUIKACHU_BGC),
 		     2, 2,
 		     GTK_ANCHOR_NW,
@@ -252,7 +252,7 @@ void Form::draw_title_nonmodal ()
 	
 	*(new Gnome::CanvasRect (*title_group))
 	    << x1 (0) << y1 (GUIKACHU_WINDOW_TITLE_HEIGHT)
-	    << x2 (res->get_width ()) << y2 (GUIKACHU_WINDOW_TITLE_HEIGHT + 1)
+	    << x2 (res->width) << y2 (GUIKACHU_WINDOW_TITLE_HEIGHT + 1)
 	    << width_units (1)
 	    << fill_color (GUIKACHU_FGC);
     }
@@ -263,22 +263,22 @@ void Form::draw_title_modal ()
     Gnome::CanvasPoints points;
     Font &font = get_title_font ();
     
-    int title_center = res->get_width () / 2;
-    int title_height = MIN (res->get_height (), 11);
+    int title_center = res->width / 2;
+    int title_height = MIN (res->height, 11);
 
-    int max_width = res->get_width ();
-    int max_height = MIN (res->get_height (), 11);
+    int max_width = res->width;
+    int max_height = MIN (res->height, 11);
 
     {
 	using namespace Gnome::CanvasHelpers;
     
 	*(new Gnome::CanvasRect (*title_group))
 	    << x1 (0) << y1 (0)
-	    << x2 (res->get_width ()) << y2 (title_height)
+	    << x2 (res->width) << y2 (title_height)
 	    << width_units (1)
 	    << fill_color (GUIKACHU_FGC);
 
-	render_text (*title_group, res->get_title (), font,
+	render_text (*title_group, res->title, font,
 		     Gdk_Color (GUIKACHU_BGC),
 		     title_center, 0,
 		     GTK_ANCHOR_N,
@@ -302,8 +302,8 @@ int Form::canvas_event_cb (GdkEvent *e)
 	
 	if (drag_occured)
 	{
-	    res->set_x ((int)(last_x - offset_x));
-	    res->set_y ((int)(last_y - offset_y));
+	    res->x = (int)(last_x - offset_x);
+	    res->y = (int)(last_y - offset_y);
 	}
     }
 
@@ -342,8 +342,8 @@ int Form::canvas_event_cb (GdkEvent *e)
 	last_x = e->button.x;
 	last_y = e->button.y;
 
-	offset_x = last_x - res->get_x ();
-	offset_y = last_y - res->get_y ();
+	offset_x = last_x - res->x;
+	offset_y = last_y - res->y;
 
 	Gdk_Cursor cursor (gdk_cursor_new (GDK_FLEUR));
 	group->grab (GDK_POINTER_MOTION_MASK | GDK_BUTTON_RELEASE_MASK,
