@@ -1,4 +1,4 @@
-//$Id: graffiti-canvas.cc,v 1.4 2001/07/24 01:48:19 cactus Exp $ -*- c++ -*-
+//$Id: graffiti-canvas.cc,v 1.5 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -49,8 +49,8 @@ void GraffitiCanvasItem::update ()
     gnome_canvas_item_new (group->gtkobj (),
 			   gnome_canvas_pixbuf_get_type (),
 			   "pixbuf", pixbuf,
-			   "x", (double)widget->get_x (),
-			   "y", (double)widget->get_y (),
+			   "x", (double)widget->x,
+			   "y", (double)widget->y,
 			   0);
     gdk_pixbuf_unref (pixbuf);
 }
