@@ -1,4 +1,4 @@
-//$Id: graffiti-prop.cc,v 1.4 2001/04/27 20:23:43 cactus Exp $ -*- c++ -*-
+//$Id: graffiti-prop.cc,v 1.8 2001/09/01 13:10:16 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,9 +22,9 @@
 #include "config.h"
 #include <libgnome/libgnome.h>
 
+#include "widget-prop.h"
+
 #include "widgets/propertytable.h"
-#include "widgets/entry.h"
-#include "widgets/pos-entry.h"
 
 using namespace Guikachu::GUI::FormEditor;
 using namespace Guikachu::Widgets;
@@ -35,36 +35,15 @@ GraffitiProperties::GraffitiProperties (Graffiti *res)
     using namespace SigC;
     
     GUI::PropertyTable *proptable = new GUI::PropertyTable ();
-    Gtk::Widget *control;
     
     /* Resource ID */
-    control = new GUI::Entry (
-	false,
-	slot (res, &Widgets::Graffiti::get_id),
-	slot (res, &Widgets::Graffiti::set_id),
-	res->changed);
-    proptable->add (_("Resource ID:"), *manage (control));
+    WidgetProperties::add_general_controls (res, *proptable);
 
     /* Separator */
     proptable->add_separator ();
 
-    /* X */
-    control = new GUI::PosEntry (
-	slot (res, &Widgets::Graffiti::get_x),
-	slot (res, &Widgets::Graffiti::set_x),
-	res->changed);
-    proptable->add (_("X:"), *manage (control),
-		    _("Horizontal position of the widget, relative "
-		      "to the parent form"));
-    
-    /* Y */
-    control = new GUI::PosEntry (
-	slot (res, &Widgets::Graffiti::get_y),
-	slot (res, &Widgets::Graffiti::set_y),
-	res->changed);
-    proptable->add (_("Y:"), *manage (control),
-		    _("Vertical position of the widget, relative "
-		      "to the parent form"));
+    /* Position */
+    WidgetProperties::add_position_controls (res, *proptable);
     
     property_editor = manage (proptable);
     gtk_object_ref (GTK_OBJECT (property_editor->gtkobj ()));
@@ -72,7 +51,7 @@ GraffitiProperties::GraffitiProperties (Graffiti *res)
 
 GraffitiProperties::~GraffitiProperties ()
 {
-    property_editor->destroy ();
+    delete property_editor;
 }
 
 Gtk::Widget* GraffitiProperties::get_editor ()
