@@ -1,4 +1,4 @@
-//$Id: graffiti.cc,v 1.3 2001/04/30 20:47:27 cactus Exp $ -*- c++ -*-
+//$Id: graffiti.cc,v 1.4 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,15 +24,10 @@
 using Guikachu::Widgets::Graffiti;
 using namespace Guikachu::GUI::FormEditor;
 
-Graffiti::Graffiti (Resources::Form *owner_,
-		    const string& id_)
+Graffiti::Graffiti (Resources::Form *owner,
+		    const string& id):
+    Widget (owner, id)
 {
-    id = id_;
-    owner = owner_;
-
-    x = 5;
-    y = 20;
-
     editor = new GraffitiProperties (this);
 }
 
@@ -93,10 +88,10 @@ void Graffiti::save (xmlNodePtr node) const
 
     /* Position */
     my_node = xmlNewChild (node, NULL, (xmlChar*) "pos", NULL);
-    buffer = g_strdup_printf ("%d", x);
+    buffer = g_strdup_printf ("%d", x ());
     xmlSetProp (my_node, (xmlChar*) "x", (xmlChar*) buffer);
     g_free (buffer);
-    buffer = g_strdup_printf ("%d", y);
+    buffer = g_strdup_printf ("%d", y ());
     xmlSetProp (my_node, (xmlChar*) "y", (xmlChar*) buffer);
     g_free (buffer);
 }
