@@ -1,4 +1,4 @@
-//$Id: label-canvas.cc,v 1.5 2001/07/24 01:48:19 cactus Exp $ -*- c++ -*-
+//$Id: label-canvas.cc,v 1.6 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -42,7 +42,7 @@ void LabelCanvasItem::update ()
     set_canvas_item (group);
 
     draw_text (*group,
-	       widget->get_text (), widget->get_font (),
-	       widget->get_x (), widget->get_y (),
-	       widget->get_usable ());
+	       widget->text, widget->font,
+	       widget->x, widget->y,
+	       widget->usable);
 }
