@@ -1,4 +1,4 @@
-//$Id: label.cc,v 1.16 2001/04/30 20:47:27 cactus Exp $ -*- c++ -*-
+//$Id: label.cc,v 1.19 2001/09/02 20:12:57 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,18 +24,12 @@
 using Guikachu::Widgets::Label;
 using namespace Guikachu::GUI::FormEditor;
 
-Label::Label (Resources::Form *owner_,
-	      const string& id_):
-    text (id_),
-    font (0),
-    usable (true)
+Label::Label (Resources::Form *owner,
+	      const string& id):
+    Widget (owner, id),
+    Textual (changed, id),
+    usable (changed, true)
 {
-    id = id_;
-    owner = owner_;
-
-    x = 5;
-    y = 20;
-
     editor = new LabelProperties (this);
 }
 
@@ -122,10 +116,10 @@ void Label::save (xmlNodePtr node) const
 
     /* Position */
     my_node = xmlNewChild (node, NULL, (xmlChar*) "pos", NULL);
-    buffer = g_strdup_printf ("%d", x);
+    buffer = g_strdup_printf ("%d", x ());
     xmlSetProp (my_node, (xmlChar*) "x", (xmlChar*) buffer);
     g_free (buffer);
-    buffer = g_strdup_printf ("%d", y);
+    buffer = g_strdup_printf ("%d", y ());
     xmlSetProp (my_node, (xmlChar*) "y", (xmlChar*) buffer);
     g_free (buffer);
 
@@ -135,8 +129,8 @@ void Label::save (xmlNodePtr node) const
     
     /* Text and font */
     my_node = xmlNewChild (node, NULL, (xmlChar*) "text",
-			   (xmlChar*) text.c_str ());
-    buffer = g_strdup_printf ("%d", font);
+			   (xmlChar*) string (text).c_str ());
+    buffer = g_strdup_printf ("%d", font ());
     xmlSetProp (my_node, (xmlChar*) "font", (xmlChar*) buffer);
     g_free (buffer);
 }
