@@ -1,4 +1,4 @@
-//$Id: label.h,v 1.7 2001/04/22 13:03:11 cactus Exp $ -*- c++ -*-
+//$Id: label.h,v 1.9 2001/08/18 16:22:55 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,7 +24,6 @@
 #include <gnome-xml/tree.h>
 #include <sigc++/basic_signal.h>
 #include "widget.h"
-#include "resource.h"
 
 namespace Guikachu
 {
@@ -34,13 +33,17 @@ namespace Guikachu
     }
 }
 
+#include "resource.h"
+#include "textual.h"
+
 #include "label-prop.h"
 
 namespace Guikachu
 {
     namespace Widgets
     {
-	class Label: public Widget
+	class Label: public Widget,
+		     public Textual
 	{
 	    GUI::FormEditor::LabelProperties *editor;
 	    
@@ -54,9 +57,7 @@ namespace Guikachu
 	    virtual GUI::FormEditor::CanvasItem *get_canvas_item (GUI::FormEditor::Form *form);
 	    virtual Gtk::Widget *get_editor ();
 	    
-	    GUIKACHU_RESOURCE_PROP (text,   string);
-	    GUIKACHU_RESOURCE_PROP (font,   int);
-	    GUIKACHU_RESOURCE_PROP (usable, bool);
+	    Property<bool>   usable;
 	    
 	private:
 	    // Persistance
