@@ -1,4 +1,4 @@
-//$Id: list-canvas.cc,v 1.6 2001/07/11 18:54:05 cactus Exp $ -*- c++ -*-
+//$Id: list-canvas.cc,v 1.8 2001/08/31 16:11:38 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -43,40 +43,39 @@ void ListCanvasItem::update ()
     group = new Gnome::CanvasGroup (*(form->get_canvas ()), 0, 0);
     set_canvas_item (group);
 
-    int font_num = widget->get_font ();    
-    int height = get_font_height (font_num) * widget->get_visible_items ();
-    int width = widget->get_width ();
-    bool usable = widget->get_usable ();    
+    int font_num = widget->font;    
+    int height = get_font_height (font_num) * widget->visible_items;
+    int width = widget->width;
+    bool usable = widget->usable;
 
     /* Render text items */
-    vector<string> listitems = widget->get_items ();
+    vector<string> listitems = widget->items;
 
     // FIXME: size() is unsigned, visible_items is signed
-    int visible_strings = MIN (widget->get_visible_items (),
+    int visible_strings = MIN (widget->visible_items,
 			       listitems.size ());
     
     int line_spacing = get_font_height (font_num);
-    int text_y = widget->get_y ();
-    int text_x = widget->get_x () + 3;
-    int max_width = 18;
-    int curr_width;
+    int text_y = widget->y;
+    int text_x = widget->x + 3;
     
     for (int i = 0; i < visible_strings; i++)
     {
-	curr_width = get_string_width (font_num, listitems[i]) + 3;
-	max_width = MAX (max_width, curr_width);
-	
 	draw_text (*group, listitems[i], font_num,
 		   text_x, text_y, usable);
 	text_y += line_spacing;
     }
 
     /* Render frame */
-    if (!widget->get_manual_width ())
-	width = max_width;
+    if (!widget->manual_width)
+    {
+	width = 18;
+	if (listitems.size ())
+	    width = get_string_width (font_num, listitems[0]) + 3;
+    }
 
-    int x1 = widget->get_x ();
-    int y1 = widget->get_y ();
+    int x1 = widget->x;
+    int y1 = widget->y;
     int x2 = x1 + width;
     int y2 = y1 + height;
     
