@@ -1,4 +1,4 @@
-//$Id: list.cc,v 1.3 2001/07/14 15:09:52 cactus Exp $ -*- c++ -*-
+//$Id: list.cc,v 1.6 2001/09/02 20:12:57 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,20 +24,17 @@
 using Guikachu::Widgets::List;
 using namespace Guikachu::GUI::FormEditor;
 
-List::List (Resources::Form *owner_,
-	    const string& id_):
-    font (0),
-    visible_items (4),
-    usable (true),
-    width (1),
-    manual_width (false)
+List::List (Resources::Form *owner,
+	    const string& id):
+    Widget (owner, id),
+    
+    font (changed, 0),
+    visible_items (changed, 4),
+    usable (changed, true),
+    items (changed, vector<string> ()),
+    width (changed, 1),
+    manual_width (changed, false)
 {
-    id = id_;
-    owner = owner_;
-
-    x = 5;
-    y = 20;
-
     editor = new ListProperties (this);
 }
 
@@ -118,10 +115,11 @@ bool List::load (xmlDocPtr doc,
 	{
 	    XML_GET_NUM_PROP (curr_node, "font", font);
 	    XML_GET_NUM_PROP (curr_node, "visible", visible_items);
-
+	    
 	    /* Iterate items */
 	    xmlNodePtr item_node;
 	    string     curr_item;
+	    vector<string> items_vec;
 	    
 	    for (item_node = curr_node->xmlChildrenNode;
 		 item_node != NULL;
@@ -130,13 +128,15 @@ bool List::load (xmlDocPtr doc,
 		if (XML_HAS_NAME (item_node, "item"))
 		{
 		    XML_GET_CONTENT (item_node, curr_item);
-		    items.push_back (curr_item);
+		    items_vec.push_back (curr_item);
 		} else {
 		    g_warning ("Error parsing `list' resource: "
 			       "unexpected element `%s/%s'",
 			       curr_node->name, item_node->name);
 		}
 	    }
+
+	    items = items_vec;
 	}
 	else
 	    g_warning ("Error parsing `list' widget: "
@@ -155,16 +155,16 @@ void List::save (xmlNodePtr node) const
 
     /* Position */
     my_node = xmlNewChild (node, NULL, (xmlChar*) "pos", NULL);
-    buffer = g_strdup_printf ("%d", x);
+    buffer = g_strdup_printf ("%d", x ());
     xmlSetProp (my_node, (xmlChar*) "x", (xmlChar*) buffer);
     g_free (buffer);
-    buffer = g_strdup_printf ("%d", y);
+    buffer = g_strdup_printf ("%d", y ());
     xmlSetProp (my_node, (xmlChar*) "y", (xmlChar*) buffer);
     g_free (buffer);
 
     /* Size */
     if (manual_width)
-	buffer = g_strdup_printf ("%d", width);
+	buffer = g_strdup_printf ("%d", width ());
     else
 	buffer = g_strdup ("auto");
     xmlSetProp (my_node, (xmlChar*) "width", (xmlChar*) buffer);
@@ -176,16 +176,17 @@ void List::save (xmlNodePtr node) const
 
     /* List items */
     my_node = xmlNewChild (node, NULL, (xmlChar*) "items", NULL);
-    buffer = g_strdup_printf ("%d", font);
+    buffer = g_strdup_printf ("%d", font ());
     xmlSetProp (my_node, (xmlChar*) "font", (xmlChar*) buffer);
     g_free (buffer);
 
-    buffer = g_strdup_printf ("%d", visible_items);
+    buffer = g_strdup_printf ("%d", visible_items ());
     xmlSetProp (my_node, (xmlChar*) "visible", (xmlChar*) buffer);
     g_free (buffer);
     
-    for (vector<string>::const_iterator i = items.begin ();
-	 i != items.end (); i++)
+    vector<string> items_vec = items;
+    for (vector<string>::const_iterator i = items_vec.begin ();
+	 i != items_vec.end (); i++)
 	xmlNewChild (my_node, NULL, (xmlChar*) "item", (xmlChar*) i->c_str ());
 }
 
@@ -194,13 +195,14 @@ void List::save_rcp (ostream &ostr) const
     gchar *width_str;
 
     if (manual_width)
-	width_str = g_strdup_printf ("%d", width);
+	width_str = g_strdup_printf ("%d", width ());
     else
 	width_str = g_strdup ("AUTO");
     
     ostr << "  LIST";
-    for (vector<string>::const_iterator i = items.begin ();
-	 i != items.end (); i++)
+    vector<string> items_vec = items ();
+    for (vector<string>::const_iterator i = items_vec.begin ();
+	 i != items_vec.end (); i++)
 	ostr << " \"" << *i << "\"";
     
     ostr << " ID " << id;
