@@ -1,4 +1,4 @@
-//$Id: palette.cc,v 1.2 2001/08/10 16:10:35 cactus Exp $ -*- c++ -*-
+//$Id: palette.cc,v 1.5 2001/09/05 17:08:53 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -37,6 +37,7 @@ using namespace Guikachu::GUI;
 #include "pixmaps/checkbox.xpm"
 #include "pixmaps/list.xpm"
 #include "pixmaps/popup-trigger.xpm"
+#include "pixmaps/scrollbar.xpm"
 
 Palette::Palette ():
     Gtk::Window (GTK_WINDOW_DIALOG),
@@ -93,6 +94,10 @@ Palette::Palette ():
     PALETTE_ADD_BUTTON(Widgets::WIDGET_POPUP_TRIGGER,
 		       _("Popup trigger"), popup_trigger_xpm,
 		       1, 2);
+
+    PALETTE_ADD_BUTTON(Widgets::WIDGET_SCROLLBAR,
+		       _("Vertical scroll bar"), scrollbar_xpm,
+		       0, 3);
 		       
 #undef PALETTE_ADD_BUTTON
 
