@@ -1,4 +1,4 @@
-//$Id: popup-trigger-canvas.cc,v 1.3 2001/07/24 01:48:19 cactus Exp $ -*- c++ -*-
+//$Id: popup-trigger-canvas.cc,v 1.4 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -30,7 +30,7 @@
 using namespace Guikachu::GUI::FormEditor;
 
 PopupTriggerCanvasItem::PopupTriggerCanvasItem (Widgets::PopupTrigger *widget_,
-						      FormEditor::Form         *form):
+						FormEditor::Form      *form):
     CanvasItem (widget_, form),
     widget (widget_),
     group (0)
@@ -47,7 +47,7 @@ void PopupTriggerCanvasItem::update ()
     set_canvas_item (group);
 
     GdkPixbuf *pixbuf = 0;
-    if (widget->get_usable ())
+    if (widget->usable)
 	pixbuf = gdk_pixbuf_new_from_xpm_data ((const char**)popup_trigger_canvas_xpm);
     else
 	pixbuf = gdk_pixbuf_new_from_xpm_data ((const char**)popup_trigger_canvas_disabled_xpm);
@@ -55,26 +55,21 @@ void PopupTriggerCanvasItem::update ()
     gnome_canvas_item_new (group->gtkobj (),
 			   gnome_canvas_pixbuf_get_type (),
 			   "pixbuf", pixbuf,
-			   "x", (double)widget->get_x (),
-			   "y", (double)widget->get_y (),
+			   "x", (double)widget->x,
+			   "y", (double)widget->y,
 			   0);
     gdk_pixbuf_unref (pixbuf);
     
-    int width = widget->get_width ();
-    int height = widget->get_height ();
-    
-    if (!widget->get_manual_width ())
-	width = get_string_width (widget->get_font (), widget->get_text ());
-    if (!widget->get_manual_height ())
-	height = get_font_height (widget->get_font ());
+    int width = widget->get_display_width ();
+    int height = widget->get_display_height ();
 
-    int text_x = widget->get_x () + 15;
-    int text_y = widget->get_y ();
+    int text_x = widget->x + 15;
+    int text_y = widget->y;
 
     draw_text (*group,
-	       widget->get_text (), widget->get_font (),
+	       widget->text, widget->font,
 	       text_x, text_y,
-	       widget->get_usable (),
+	       widget->usable,
 	       GTK_ANCHOR_NW,
 	       width, height);
 }
