@@ -1,4 +1,4 @@
-//$Id: popup-trigger.cc,v 1.2 2001/07/14 15:09:52 cactus Exp $ -*- c++ -*-
+//$Id: popup-trigger.cc,v 1.5 2001/09/02 20:12:57 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,28 +19,22 @@
 #include "popup-trigger.h"
 #include "popup-trigger-canvas.h"
 
+#include "form-editor.h"
+
 #include <gnome-xml/xmlmemory.h>
 
 using Guikachu::Widgets::PopupTrigger;
 using namespace Guikachu::GUI::FormEditor;
 
-PopupTrigger::PopupTrigger (Resources::Form *owner_,
-			    const string& id_):
-    text (id_),
-    font (0),
-    usable (true),
-    anchor_right (false),
-    width (1),
-    manual_width (false),
-    height (1),
-    manual_height (false)
+PopupTrigger::PopupTrigger (Resources::Form *owner,
+			    const string& id):
+    Widget (owner, id),
+    Resizeable (changed),
+    Textual (changed, id),
+    list_id (changed, ""),
+    usable (changed, true),
+    anchor_right (changed, false)
 {
-    id = id_;
-    owner = owner_;
-
-    x = 5;
-    y = 20;
-
     editor = new PopupTriggerProperties (this);
 }
 
@@ -168,23 +162,23 @@ void PopupTrigger::save (xmlNodePtr node) const
 
     /* Position */
     my_node = xmlNewChild (node, NULL, (xmlChar*) "pos", NULL);
-    buffer = g_strdup_printf ("%d", x);
+    buffer = g_strdup_printf ("%d", x ());
     xmlSetProp (my_node, (xmlChar*) "x", (xmlChar*) buffer);
     g_free (buffer);
-    buffer = g_strdup_printf ("%d", y);
+    buffer = g_strdup_printf ("%d", y ());
     xmlSetProp (my_node, (xmlChar*) "y", (xmlChar*) buffer);
     g_free (buffer);
 
     /* Frame */
     if (manual_width)
-	buffer = g_strdup_printf ("%d", width);
+	buffer = g_strdup_printf ("%d", width ());
     else
 	buffer = g_strdup ("auto");
     xmlSetProp (my_node, (xmlChar*) "width", (xmlChar*) buffer);
     g_free (buffer);
 
     if (manual_height)
-	buffer = g_strdup_printf ("%d", height);
+	buffer = g_strdup_printf ("%d", height ());
     else
 	buffer = g_strdup ("auto");
     xmlSetProp (my_node, (xmlChar*) "height", (xmlChar*) buffer);
@@ -193,7 +187,7 @@ void PopupTrigger::save (xmlNodePtr node) const
     if (list_id != "")
     {
 	my_node = xmlNewChild (node, NULL, (xmlChar*) "popuplist", NULL);
-	xmlSetProp (my_node, (xmlChar*) "id", (xmlChar*)list_id.c_str ());
+	xmlSetProp (my_node, (xmlChar*) "id", (xmlChar*)list_id ().c_str ());
     }
     
     /* Usable */
@@ -206,8 +200,8 @@ void PopupTrigger::save (xmlNodePtr node) const
     
     /* Label and font */
     my_node = xmlNewChild (node, NULL, (xmlChar*) "text",
-			   (xmlChar*) text.c_str ());
-    buffer = g_strdup_printf ("%d", font);
+			   (xmlChar*) text ().c_str ());
+    buffer = g_strdup_printf ("%d", font ());
     xmlSetProp (my_node, (xmlChar*) "font", (xmlChar*) buffer);
     g_free (buffer);
 }
@@ -217,12 +211,12 @@ void PopupTrigger::save_rcp (ostream &ostr) const
     gchar *width_str, *height_str;
 
     if (manual_width)
-	width_str = g_strdup_printf ("%d", width);
+	width_str = g_strdup_printf ("%d", width ());
     else
 	width_str = g_strdup ("AUTO");
     
     if (manual_height)
-	height_str = g_strdup_printf ("%d", height);
+	height_str = g_strdup_printf ("%d", height ());
     else
 	height_str = g_strdup ("AUTO");
 
@@ -251,3 +245,21 @@ CanvasItem* PopupTrigger::get_canvas_item (GUI::FormEditor::Form *form)
 {
     return new PopupTriggerCanvasItem (this, form);
 }
+
+int PopupTrigger::get_display_width ()
+{
+    if (manual_width)
+	return width;
+
+    int text_width = get_string_width (font, text);
+    return text_width;
+}
+
+int PopupTrigger::get_display_height ()
+{
+    if (manual_height)
+	return height;
+
+    int text_height = get_font_height (font);
+    return text_height;
+}
