@@ -1,4 +1,4 @@
-//$Id: popup-trigger.h,v 1.1 2001/07/11 19:26:46 cactus Exp $ -*- c++ -*-
+//$Id: popup-trigger.h,v 1.3 2001/08/18 16:22:55 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -34,13 +34,18 @@ namespace Guikachu
     }
 }
 
+#include "resizeable.h"
+#include "textual.h"
+
 #include "popup-trigger-prop.h"
 
 namespace Guikachu
 {
     namespace Widgets
     {
-	class PopupTrigger: public Widget
+	class PopupTrigger: public Widget,
+			    public Resizeable,
+			    public Textual
 	{
 	    GUI::FormEditor::PopupTriggerProperties *editor;
 	    
@@ -53,19 +58,14 @@ namespace Guikachu
 	    
 	    virtual GUI::FormEditor::CanvasItem *get_canvas_item (GUI::FormEditor::Form *form);
 	    virtual Gtk::Widget *get_editor ();
-	    
-	    GUIKACHU_RESOURCE_PROP (text,          string);
-	    GUIKACHU_RESOURCE_PROP (font,          int);
 
-	    GUIKACHU_RESOURCE_PROP (list_id,       string);
-	    
-	    GUIKACHU_RESOURCE_PROP (usable,        bool);
-	    GUIKACHU_RESOURCE_PROP (anchor_right,  bool);
+	    virtual int get_display_width ();
+	    virtual int get_display_height ();
 
-	    GUIKACHU_RESOURCE_PROP (width,         int);
-	    GUIKACHU_RESOURCE_PROP (manual_width,  bool);
-	    GUIKACHU_RESOURCE_PROP (height,        int);
-	    GUIKACHU_RESOURCE_PROP (manual_height, bool);
+	    Property<string> list_id;
+
+	    Property<bool>   usable;
+	    Property<bool>   anchor_right;
 	    
 	private:
 	    // Persistance
