@@ -1,4 +1,4 @@
-//$Id: pushbutton-canvas.cc,v 1.6 2001/07/24 01:48:19 cactus Exp $ -*- c++ -*-
+//$Id: pushbutton-canvas.cc,v 1.7 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -41,21 +41,13 @@ void PushButtonCanvasItem::update ()
     group = new Gnome::CanvasGroup (*(form->get_canvas ()), 0, 0);
     set_canvas_item (group);
     
-    int width = widget->get_width ();
-    int height = widget->get_height ();
-    
-    int text_width = get_string_width (widget->get_font (), widget->get_text ());
-    int text_height = get_font_height (widget->get_font ());
-    
-    if (!widget->get_manual_width ())
-	width = 2 + text_width + 2;
-    if (!widget->get_manual_height ())
-	height = text_height;
+    int width = widget->get_display_width ();
+    int height = widget->get_display_height ();
 
     /* Don't ask about the +1, I have no idea... */
-    int x1 = widget->get_x ();
+    int x1 = widget->x;
     int x2 = x1 + width + 1;
-    int y1 = widget->get_y ();
+    int y1 = widget->y;
     int y2 = y1 + height + 2;
 
     /* A Polygon is used instead of a Rectangle to get mouse events
@@ -73,18 +65,18 @@ void PushButtonCanvasItem::update ()
     Gnome::CanvasPolygon *frame_item = new Gnome::CanvasPolygon (*group, frame_points);
     frame_item->set_width_units (1);
 
-    if (widget->get_usable ())
+    if (widget->usable)
 	frame_item->set_outline_color (GUIKACHU_FGC);
     else
 	frame_item->set_outline_color (GUIKACHU_FGC_DISABLED);
     
-    int text_x = widget->get_x () + width / 2;
-    int text_y = widget->get_y () + height / 2 + 1;
+    int text_x = x1 + width / 2;
+    int text_y = y1 + height / 2 + 1;
 
     draw_text (*group,
-	       widget->get_text (), widget->get_font (),
+	       widget->text, widget->font,
 	       text_x, text_y,
-	       widget->get_usable (),
+	       widget->usable,
 	       GTK_ANCHOR_CENTER,
 	       width, height);
 }
