@@ -1,4 +1,4 @@
-//$Id: selector-trigger-canvas.cc,v 1.7 2001/07/24 01:48:19 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger-canvas.cc,v 1.8 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -41,21 +41,13 @@ void SelectorTriggerCanvasItem::update ()
     group = new Gnome::CanvasGroup (*(form->get_canvas ()), 0, 0);
     set_canvas_item (group);
     
-    int width = widget->get_width ();
-    int height = widget->get_height ();
-    
-    int text_width = get_string_width (widget->get_font (), widget->get_text ());
-    int text_height = get_font_height (widget->get_font ());
-    
-    if (!widget->get_manual_width ())
-	width = 2 + text_width + 2;
-    if (!widget->get_manual_height ())
-	height = text_height + 1;
+    int width = widget->get_display_width ();
+    int height = widget->get_display_height ();
 
     /* Don't ask about the +1, I have no idea... */
-    int x1 = widget->get_x ();
+    int x1 = widget->x;
     int x2 = x1 + width + 1;
-    int y1 = widget->get_y ();
+    int y1 = widget->y;
     int y2 = y1 + height + 1;
 
     /* A Polygon is used instead of a Rectangle to get mouse events
@@ -83,18 +75,18 @@ void SelectorTriggerCanvasItem::update ()
     frame_item->set_outline_stipple (stipple);
     gdk_bitmap_unref (stipple);
 
-    if (widget->get_usable ())
+    if (widget->usable)
 	frame_item->set_outline_color (GUIKACHU_FGC);
     else
 	frame_item->set_outline_color (GUIKACHU_FGC_DISABLED);
     
-    int text_x = widget->get_x () + 4;
-    int text_y = widget->get_y () + height / 2;
+    int text_x = x1 + 4;
+    int text_y = y1 + height / 2;
 
     draw_text (*group,
-	       widget->get_text (), widget->get_font (),
+	       widget->text, widget->font,
 	       text_x, text_y,
-	       widget->get_usable (),
+	       widget->usable,
 	       GTK_ANCHOR_WEST,
 	       width, height);
 }
