@@ -1,4 +1,4 @@
-//$Id: selector-trigger.cc,v 1.3 2001/04/30 20:47:27 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger.cc,v 1.6 2001/09/02 20:12:57 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,28 +19,21 @@
 #include "selector-trigger.h"
 #include "selector-trigger-canvas.h"
 
+#include "form-editor.h"
+
 #include <gnome-xml/xmlmemory.h>
 
 using Guikachu::Widgets::SelectorTrigger;
 using namespace Guikachu::GUI::FormEditor;
 
-SelectorTrigger::SelectorTrigger (Resources::Form *owner_,
-				  const string& id_):
-    text (id_),
-    font (0),
-    usable (true),
-    anchor_right (false),
-    width (1),
-    manual_width (false),
-    height (1),
-    manual_height (false)
+SelectorTrigger::SelectorTrigger (Resources::Form *owner,
+				  const string& id):
+    Widget (owner, id),
+    Resizeable (changed),
+    Textual (changed, id),
+    usable (changed, true),
+    anchor_right (changed, false)
 {
-    id = id_;
-    owner = owner_;
-
-    x = 5;
-    y = 20;
-
     editor = new SelectorTriggerProperties (this);
 }
 
@@ -161,23 +154,23 @@ void SelectorTrigger::save (xmlNodePtr node) const
 
     /* Position */
     my_node = xmlNewChild (node, NULL, (xmlChar*) "pos", NULL);
-    buffer = g_strdup_printf ("%d", x);
+    buffer = g_strdup_printf ("%d", x ());
     xmlSetProp (my_node, (xmlChar*) "x", (xmlChar*) buffer);
     g_free (buffer);
-    buffer = g_strdup_printf ("%d", y);
+    buffer = g_strdup_printf ("%d", y ());
     xmlSetProp (my_node, (xmlChar*) "y", (xmlChar*) buffer);
     g_free (buffer);
 
     /* Frame */
     if (manual_width)
-	buffer = g_strdup_printf ("%d", width);
+	buffer = g_strdup_printf ("%d", width ());
     else
 	buffer = g_strdup ("auto");
     xmlSetProp (my_node, (xmlChar*) "width", (xmlChar*) buffer);
     g_free (buffer);
 
     if (manual_height)
-	buffer = g_strdup_printf ("%d", height);
+	buffer = g_strdup_printf ("%d", height ());
     else
 	buffer = g_strdup ("auto");
     xmlSetProp (my_node, (xmlChar*) "height", (xmlChar*) buffer);
@@ -193,8 +186,8 @@ void SelectorTrigger::save (xmlNodePtr node) const
     
     /* Label and font */
     my_node = xmlNewChild (node, NULL, (xmlChar*) "text",
-			   (xmlChar*) text.c_str ());
-    buffer = g_strdup_printf ("%d", font);
+			   (xmlChar*) string (text).c_str ());
+    buffer = g_strdup_printf ("%d", font ());
     xmlSetProp (my_node, (xmlChar*) "font", (xmlChar*) buffer);
     g_free (buffer);
 }
@@ -204,12 +197,12 @@ void SelectorTrigger::save_rcp (ostream &ostr) const
     gchar *width_str, *height_str;
 
     if (manual_width)
-	width_str = g_strdup_printf ("%d", width);
+	width_str = g_strdup_printf ("%d", width ());
     else
 	width_str = g_strdup ("AUTO");
     
     if (manual_height)
-	height_str = g_strdup_printf ("%d", height);
+	height_str = g_strdup_printf ("%d", height ());
     else
 	height_str = g_strdup ("AUTO");
 
@@ -235,3 +228,22 @@ CanvasItem* SelectorTrigger::get_canvas_item (GUI::FormEditor::Form *form)
 {
     return new SelectorTriggerCanvasItem (this, form);
 }
+
+int SelectorTrigger::get_display_width ()
+{
+    if (manual_width)
+	return width;
+
+    int text_width = get_string_width (font, text);
+    return 2 + text_width + 2;
+}
+
+int SelectorTrigger::get_display_height ()
+{
+    if (manual_height)
+	return height;
+
+    int text_height = get_font_height (font);
+    return text_height + 1;
+
+}
