@@ -1,4 +1,4 @@
-//$Id: selector-trigger.h,v 1.1 2001/04/29 20:00:12 cactus Exp $ -*- c++ -*-
+//$Id: selector-trigger.h,v 1.3 2001/08/19 15:02:33 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,9 +22,6 @@
 #include <string>
 #include <iostream>
 #include <gnome-xml/tree.h>
-#include <sigc++/basic_signal.h>
-#include "widget.h"
-#include "resource.h"
 
 namespace Guikachu
 {
@@ -34,13 +31,19 @@ namespace Guikachu
     }
 }
 
+#include "widget.h"
+#include "resizeable.h"
+#include "textual.h"
+
 #include "selector-trigger-prop.h"
 
 namespace Guikachu
 {
     namespace Widgets
     {
-	class SelectorTrigger: public Widget
+	class SelectorTrigger: public Widget,
+			       public Resizeable,
+			       public Textual
 	{
 	    GUI::FormEditor::SelectorTriggerProperties *editor;
 	    
@@ -53,18 +56,13 @@ namespace Guikachu
 	    
 	    virtual GUI::FormEditor::CanvasItem *get_canvas_item (GUI::FormEditor::Form *form);
 	    virtual Gtk::Widget *get_editor ();
-	    
-	    GUIKACHU_RESOURCE_PROP (text,          string);
-	    GUIKACHU_RESOURCE_PROP (font,          int);
 
-	    GUIKACHU_RESOURCE_PROP (usable,        bool);
-	    GUIKACHU_RESOURCE_PROP (anchor_right,  bool);
+	    virtual int get_display_width ();
+	    virtual int get_display_height ();
+
+	    Property<bool>   usable;
+	    Property<bool>   anchor_right;
 
-	    GUIKACHU_RESOURCE_PROP (width,         int);
-	    GUIKACHU_RESOURCE_PROP (manual_width,  bool);
-	    GUIKACHU_RESOURCE_PROP (height,        int);
-	    GUIKACHU_RESOURCE_PROP (manual_height, bool);
-	    
 	private:
 	    // Persistance
 	    virtual bool load (xmlDocPtr xml_doc, xmlNodePtr node);
