@@ -1,4 +1,4 @@
-//$Id: widget.cc,v 1.10 2001/05/11 16:37:08 cactus Exp $ -*- c++ -*-
+//$Id: widget.cc,v 1.11 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,18 +22,14 @@
 
 using namespace Guikachu;
 
-string Widgets::Widget::get_id ()
+Widgets::Widget::Widget (Resources::Form *owner_,
+			 const string&    id_):
+    owner (owner_),
+    id (changed, id_),
+    x (changed, 0),
+    y (changed, 0)
 {
-    return id;
-}
-
-void Widgets::Widget::set_id (const string& new_id)
-{
-    if (ResourceManager::rename_resource (id, new_id))
-	id = new_id;
-
-    changed ();
-}
+}   
 
 ostream& Widgets::operator<< (ostream &ostr, const Widget* res)
 {
