@@ -1,4 +1,4 @@
-//$Id: form-res-io.cc,v 1.14 2001/07/11 19:26:46 cactus Exp $ -*- c++ -*-
+//$Id: form-res-io.cc,v 1.17 2001/09/05 17:08:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -175,6 +175,8 @@ Widgets::Widget* Form::load_widget (xmlDocPtr doc,
 	widget = create_widget (Widgets::WIDGET_LIST, id);
     else if (!strcmp (node_name, "popup_trigger"))
 	widget = create_widget (Widgets::WIDGET_POPUP_TRIGGER, id);
+    else if (!strcmp (node_name, "scrollbar"))
+	widget = create_widget (Widgets::WIDGET_SCROLLBAR, id);
     else
 	g_warning ("Unknown widget type `%s'", node_name);
 
@@ -191,21 +193,21 @@ void Form::save (xmlNodePtr node) const
 
     /* Title */
     my_node = xmlNewChild (node, NULL, (xmlChar*) "title",
-			   (xmlChar*)title.c_str ());
+			   (xmlChar*)title ().c_str ());
 
     /* Position */
     gchar *buffer;
     my_node = xmlNewChild (node, NULL, (xmlChar*) "pos", NULL);
-    buffer = g_strdup_printf ("%d", x);
+    buffer = g_strdup_printf ("%d", x ());
     xmlSetProp (my_node, (xmlChar*) "x", (xmlChar*)buffer);
     g_free (buffer);
-    buffer = g_strdup_printf ("%d", y);
+    buffer = g_strdup_printf ("%d", y ());
     xmlSetProp (my_node, (xmlChar*) "y", (xmlChar*)buffer);
     g_free (buffer);
-    buffer = g_strdup_printf ("%d", width);
+    buffer = g_strdup_printf ("%d", width ());
     xmlSetProp (my_node, (xmlChar*) "width", (xmlChar*)buffer);
     g_free (buffer);
-    buffer = g_strdup_printf ("%d", height);
+    buffer = g_strdup_printf ("%d", height ());
     xmlSetProp (my_node, (xmlChar*) "height", (xmlChar*)buffer);
     g_free (buffer);
     
@@ -214,14 +216,14 @@ void Form::save (xmlNodePtr node) const
     if (help_id != "")
     {
 	my_node = xmlNewChild (node, NULL, (xmlChar*) "help", NULL);
-	xmlSetProp (my_node, (xmlChar*) "id", (xmlChar*)help_id.c_str ());    
+	xmlSetProp (my_node, (xmlChar*) "id", (xmlChar*)help_id ().c_str ());
     }
 
     /* Menu ID */
     if (menu_id != "")
     {
 	my_node = xmlNewChild (node, NULL, (xmlChar*) "menu", NULL);
-	xmlSetProp (my_node, (xmlChar*) "id", (xmlChar*)menu_id.c_str ());    
+	xmlSetProp (my_node, (xmlChar*) "id", (xmlChar*)menu_id ().c_str ());
     }
 
     if (modal)
@@ -243,7 +245,7 @@ void Form::save (xmlNodePtr node) const
 
 	if (def_button != "")
 	    xmlSetProp (widgetlist_node,
-			(xmlChar*) "default", (xmlChar*) def_button.c_str ());
+			(xmlChar*) "default", (xmlChar*) def_button ().c_str ());
 	
 	for (set<Widgets::Widget*>::const_iterator i = widgets.begin ();
 	     i != widgets.end (); i++)
@@ -276,7 +278,10 @@ void Form::save (xmlNodePtr node) const
 	    case Widgets::WIDGET_POPUP_TRIGGER:
 		curr_node_name = (xmlChar*) "popup_trigger";
 		break;
-	    default:
+	    case Widgets::WIDGET_SCROLLBAR:
+		curr_node_name = (xmlChar*) "scrollbar";
+		break;
+	    case Widgets::WIDGET_NONE:
 		g_assert_not_reached ();
 		break;
 	    }
@@ -284,7 +289,7 @@ void Form::save (xmlNodePtr node) const
 	    widget_node = xmlNewChild (widgetlist_node, NULL, curr_node_name, NULL);
 	    xmlSetProp (widget_node,
 			(xmlChar*)"id",
-			(xmlChar*)(*i)->get_id ().c_str ());
+			(xmlChar*)(*i)->id ().c_str ());
 	    (*i)->save (widget_node);
 	}
     }
