@@ -1,4 +1,4 @@
-//$Id: form-res.cc,v 1.16 2001/07/11 19:26:46 cactus Exp $ -*- c++ -*-
+//$Id: form-res.cc,v 1.19 2001/09/05 17:08:52 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -27,23 +27,26 @@
 #include "form-editor/checkbox.h"
 #include "form-editor/list.h"
 #include "form-editor/popup-trigger.h"
+#include "form-editor/scrollbar.h"
 
 using namespace Guikachu::Resources;
 using namespace Guikachu;
 
-Form::Form (const string& id_):
-    gui (0)
+Form::Form (const string& id):
+    Resource (id),
+    gui (0),
+    title (changed, id),
+    help_id (changed, ""),
+    menu_id (changed, ""),
+    modal (changed, false),
+    frame (changed, true),
+    savebehind (changed, true),
+    def_button (changed, ""),
+    x (changed),
+    y (changed),
+    width (changed, 160),
+    height (changed, 160)
 {
-    id = id_;
-
-    modal = false;
-    frame = true;
-    savebehind = false;
-
-    title = id;
-    
-    x = y = 0;
-    width = height = 160;
 }
 
 Form::~Form ()
@@ -51,7 +54,7 @@ Form::~Form ()
     for (set<Widgets::Widget*>::iterator i = widgets.begin ();
 	 i != widgets.end (); i++)
     {
-	ResourceManager::unregister_id ((*i)->get_id ());
+	ResourceManager::unregister_id ((*i)->id);
 	delete (*i);
 	widgets.erase (i);
     }
@@ -97,7 +100,10 @@ Widgets::Widget* Form::create_widget (Widgets::Type type)
     case Widgets::WIDGET_POPUP_TRIGGER:
 	prefix = "popup_trigger";
 	break;
-    default:
+    case Widgets::WIDGET_SCROLLBAR:
+	prefix = "scrollbar";
+	break;
+    case Widgets::WIDGET_NONE:
 	g_assert_not_reached ();
 	return 0;
 	break;
@@ -140,7 +146,10 @@ Widgets::Widget* Form::create_widget (Widgets::Type type,
     case Widgets::WIDGET_POPUP_TRIGGER:
 	widget = new Widgets::PopupTrigger (this, id);
 	break;
-    default:
+    case Widgets::WIDGET_SCROLLBAR:
+	widget = new Widgets::ScrollBar (this, id);
+	break;
+    case Widgets::WIDGET_NONE:
 	g_assert_not_reached ();
 	return 0;
 	break;
@@ -161,7 +170,7 @@ void Form::remove_widget (Widgets::Widget *widget)
     widget_removed.emit (widget);
 
     widgets.erase (widget);
-    ResourceManager::unregister_id (widget->get_id ());
+    ResourceManager::unregister_id (widget->id);
     
     delete widget;
 
@@ -173,7 +182,7 @@ Widgets::Widget* Form::get_widget (const string& id) const
     set<Widgets::Widget*>::const_iterator found;
 
     found = widgets.begin ();
-    while (found != widgets.end () && (*found)->get_id () != id)
+    while (found != widgets.end () && (*found)->id != id)
 	found++;
 
     if (found == widgets.end ())
