@@ -1,4 +1,4 @@
-//$Id: form-res.h,v 1.8 2001/04/21 13:02:59 cactus Exp $ -*- c++ -*-
+//$Id: form-res.h,v 1.9 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -49,21 +49,20 @@ namespace Guikachu
 	    virtual Type get_type () const { return RESOURCE_FORM; };
 	    virtual void show_ui ();
 
-	    GUIKACHU_RESOURCE_PROP(title,	string);
+	    Property<string> title;
+	    Property<string> help_id;
+	    Property<string> menu_id;
 
-	    GUIKACHU_RESOURCE_PROP(help_id,	string);
-	    GUIKACHU_RESOURCE_PROP(menu_id,	string);
-	    
-	    GUIKACHU_RESOURCE_PROP(modal,	bool);
-	    GUIKACHU_RESOURCE_PROP(frame,	bool);
-	    GUIKACHU_RESOURCE_PROP(savebehind,	bool);
+	    Property<bool>   modal;
+	    Property<bool>   frame;
+	    Property<bool>   savebehind;
 
-	    GUIKACHU_RESOURCE_PROP(def_button,  string);
-	    
-	    GUIKACHU_RESOURCE_PROP(x,		int);
-	    GUIKACHU_RESOURCE_PROP(y,		int);
-	    GUIKACHU_RESOURCE_PROP(width,	int);
-	    GUIKACHU_RESOURCE_PROP(height,	int);
+	    Property<string> def_button;
+
+	    Property<int>    x;
+	    Property<int>    y;
+	    Property<int>    width;
+	    Property<int>    height;
 
 	    const set<Widgets::Widget*>& get_widgets () const { return widgets; };
 	    Widgets::Widget*             get_widget (const string& id) const;
