@@ -1,4 +1,4 @@
-//$Id: form-win-helpers.cc,v 1.3 2001/04/28 16:26:29 cactus Exp $ -*- c++ -*-
+//$Id: form-win-helpers.cc,v 1.4 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -32,7 +32,7 @@ using namespace Guikachu::GUI::FormWindow_Helpers;
  ***********************************/
 
 WidgetTreeItem::WidgetTreeItem (Widgets::Widget *widget_):
-    Gtk::TreeItem (widget_->get_id ()),
+    Gtk::TreeItem (widget_->id),
     widget (widget_)
 {
     using namespace Gnome;
@@ -53,7 +53,7 @@ WidgetTreeItem::WidgetTreeItem (Widgets::Widget *widget_):
 void WidgetTreeItem::update ()
 {
     remove ();
-    add_label (widget->get_id ());
+    add_label (widget->id);
 }
 
 int WidgetTreeItem::button_press_cb (GdkEventButton *e)
@@ -78,7 +78,7 @@ void WidgetTreeItem::remove_cb ()
  ***********************************/
 
 TopTreeItem::TopTreeItem (Resources::Form *res_):
-    Gtk::TreeItem (res_->get_id ()),
+    Gtk::TreeItem (res_->id),
     res (res_)
 {
     set_user_data (res);
@@ -90,7 +90,7 @@ TopTreeItem::TopTreeItem (Resources::Form *res_):
 void TopTreeItem::update ()
 {
     remove ();
-    add_label (res->get_id ());
+    add_label (res->id);
 }
 
 int TopTreeItem::button_press_cb (GdkEventButton *e)
