@@ -1,4 +1,4 @@
-//$Id: form-win.cc,v 1.22 2001/08/10 16:10:34 cactus Exp $ -*- c++ -*-
+//$Id: form-win.cc,v 1.26 2001/08/31 16:11:37 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -95,7 +95,8 @@ FormWindow::FormWindow (Form *res_):
 
 FormWindow::~FormWindow ()
 {
-    window->destroy ();
+//    window->destroy ();
+    gtk_widget_destroy (GTK_WIDGET (window->gtkobj ()));
     gtk_object_unref (GTK_OBJECT (gui));
 
     delete form;
@@ -107,6 +108,7 @@ void FormWindow::show ()
     window->show_all ();
     window->get_window ().raise ();
     palette->show_all ();
+    palette->get_window ().raise ();
     
     if (edited_widget)
 	edited_widget->show_editor ();
@@ -129,10 +131,26 @@ int FormWindow::property_delete_event_impl (GdkEventAny *e)
 
 void FormWindow::update ()
 {
-    gchar *title_buf = g_strdup_printf (_("Form: %s"), res->get_id ().c_str ());
+    gchar *title_buf = g_strdup_printf (_("Form: %s"), res->id ().c_str ());
     window->set_title (title_buf);
     g_free (title_buf);
 
+    if (!edited_widget)
+    {
+	gchar *prop_buf = g_strdup_printf (_("Properties: %s"), res->id ().c_str ());
+	property_window->set_title (prop_buf);
+	g_free (prop_buf);
+    }
+
+}
+
+void FormWindow::edited_widget_changed ()
+{
+    g_return_if_fail (edited_widget != 0);
+
+    gchar *buffer = g_strdup_printf (_("Properties: %s"), edited_widget->id ().c_str ());
+    property_window->set_title (buffer);
+    g_free (buffer);
 }
 
 void FormWindow::widget_created_cb (Widgets::Widget *widget)
@@ -188,8 +206,8 @@ int FormWindow::canvas_overlay_cb (GdkEvent *event)
     if (event->button.button != 1)
 	return false;
     
-    add_widget (event->button.x - res->get_x (),
-		event->button.y - res->get_y ());
+    add_widget (event->button.x - res->x,
+		event->button.y - res->y);
     
     palette->palette_applied ();
 
@@ -223,8 +241,8 @@ void FormWindow::palette_cb (Widgets::Type type)
     // Create overlay canvas item
     Gnome::CanvasPoints   points;
 
-    int x = res->get_x ();
-    int y = res->get_y ();
+    int x = res->x;
+    int y = res->y;
     
     points.push_back (Gnome::Art::Point (x, y));
     points.push_back (Gnome::Art::Point (GUIKACHU_SCREEN_WIDTH + x, y));
@@ -241,8 +259,8 @@ void FormWindow::add_widget (int x, int y)
 {
     Widgets::Widget *widget = res->create_widget (selected_widget_type);
 
-    widget->set_x (x);
-    widget->set_y (y);
+    widget->x = x;
+    widget->y = y;
 }
 
 void FormWindow::show_property_editor (Widgets::Widget *widget)
@@ -256,23 +274,25 @@ void FormWindow::show_property_editor (Widgets::Widget *widget)
     }
 
     edited_widget = widget;
+    edited_widget_changed_conn.disconnect ();
+    edited_widget_changed_conn = edited_widget->changed.connect (
+	SigC::slot (this, &FormWindow::edited_widget_changed));
+    
     Gtk::Widget *editor = widget->get_editor ();
     
     property_window->remove ();
     property_window->add (*editor);
-
-    gchar *buffer = g_strdup_printf (_("Properties: %s"),
-				     widget->get_id ().c_str ());
-    property_window->set_title (buffer);
-    g_free (buffer);
     
     property_window->show_all ();
     property_window->get_window ().raise ();
+
+    edited_widget_changed ();
 }
 
 void FormWindow::show_form_property_editor ()
 {
     edited_widget = 0;
+    edited_widget_changed_conn.disconnect ();
     
     Gtk::Widget *editor = form->get_editor ();
     
@@ -282,8 +302,7 @@ void FormWindow::show_form_property_editor ()
 	property_window->add (*editor);
     }
     
-    gchar *buffer = g_strdup_printf (_("Properties: %s"),
-				     res->get_id ().c_str());
+    gchar *buffer = g_strdup_printf (_("Properties: %s"), res->id ().c_str());
     property_window->set_title (buffer);
     g_free (buffer);
     
