@@ -1,4 +1,4 @@
-//$Id: form-win.h,v 1.12 2001/08/10 16:10:34 cactus Exp $ -*- c++ -*-
+//$Id: form-win.h,v 1.13 2001/08/31 16:11:37 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -54,6 +54,7 @@ namespace Guikachu
 	    FormEditor::Form           *form;
 
 	    Widgets::Widget            *edited_widget;
+	    SigC::Connection            edited_widget_changed_conn;
 
 	    Gnome::CanvasItem          *canvas_overlay;
 	    Widgets::Type               selected_widget_type;	    
@@ -70,6 +71,7 @@ namespace Guikachu
 	    int delete_event_impl (GdkEventAny *e);
 	    int property_delete_event_impl (GdkEventAny *e);
 	    void update ();
+	    void edited_widget_changed ();
 
 	    void palette_cb (Widgets::Type type);
 	    int canvas_overlay_cb (GdkEvent *event);
