@@ -1,4 +1,4 @@
-//$Id: main.cc,v 1.6 2001/07/08 17:03:10 cactus Exp $ -*- c++ -*-
+//$Id: main.cc,v 1.9 2001/08/12 23:24:15 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -19,14 +19,17 @@
 #include "config.h"
 
 #include <gnome--/main.h>
+
+#ifdef USE_WM_ICONS
+#include <libgnomeui/gnome-window-icon.h>
+#endif
+
 #include <glade/glade.h>
 #include <fcntl.h>
 
 #include "mainwin.h"
 #include "resource-manager.h"
 
-#include <string>
-
 namespace Guikachu
 {
     enum FileType
@@ -100,7 +103,7 @@ static bool check_files ()
     };
 
     for (unsigned int i = 0;
-	 i < (sizeof (files) / sizeof (FileEntry*) - 1);
+	 i < (sizeof (files) / sizeof (FileEntry));
 	 i++)
     {
 	if (!check_file (files[i]))
@@ -122,7 +125,7 @@ static bool check_files ()
 int main (int argc, char **argv)
 {
 #ifdef ENABLE_NLS
-    bindtextdomain (PACKAGE, GNOMELOCALEDIR);
+    bindtextdomain (PACKAGE, GNOME_LOCALEDIR);
     textdomain (PACKAGE);
 #endif
 
@@ -133,6 +136,10 @@ int main (int argc, char **argv)
     if (!check_files ())
 	return -1;
 
+#ifdef USE_WM_ICONS
+    gnome_window_icon_set_default_from_file (GNOME_ICONDIR "/guikachu.png");
+#endif    
+
     ResourceManager::reset ();
     GUI::MainWin w;
 
