@@ -1,4 +1,4 @@
-//$Id: menu-res.cc,v 1.7 2001/05/17 22:08:54 cactus Exp $ -*- c++ -*-
+//$Id: menu-res.cc,v 1.9 2001/09/02 20:06:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -23,10 +23,10 @@
 using namespace Guikachu;
 using namespace Guikachu::Resources;
 
-Menu::Menu (const string& id_):
+Menu::Menu (const string& id):
+    Resource (id),
     gui (0)
 {
-    id = id_;
 }
 
 Menu::~Menu ()
