@@ -1,4 +1,4 @@
-//$Id: resource-manager-io.cc,v 1.9 2001/04/27 21:32:11 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager-io.cc,v 1.10 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -145,9 +145,10 @@ void ResourceManager::save (const string& filename)
 	 i != resource_map.end ();
 	 i++)
     {
+	Resources::Resource *resource = i->second;
 	xmlChar *curr_node_name = 0;
 
-	switch (i->second->get_type ())
+	switch (resource->get_type ())
 	{
 	case Resources::RESOURCE_STRING:
 	    curr_node_name = (xmlChar*) "string";
@@ -164,8 +165,8 @@ void ResourceManager::save (const string& filename)
 	}
 	
 	node = xmlNewChild (root, NULL, curr_node_name, NULL);
-	xmlSetProp (node, (xmlChar*)"id", (xmlChar*)i->second->get_id ().c_str ());
-	i->second->save (node);
+	xmlSetProp (node, (xmlChar*)"id", (xmlChar*)resource->id ().c_str ());
+	resource->save (node);
     }
     
     xmlSaveFile (filename.c_str(), doc);
