@@ -1,4 +1,4 @@
-//$Id: resource-manager.cc,v 1.8 2001/04/21 13:02:59 cactus Exp $ -*- c++ -*-
+//$Id: resource-manager.cc,v 1.9 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -160,8 +160,8 @@ void ResourceManager::remove_resource (Resources::Resource* resource)
 {
     resource_removed.emit (resource);
 
-    unregister_id (resource->get_id ());
-    resource_map.erase (resource->get_id ());
+    unregister_id (resource->id);
+    resource_map.erase (resource->id ());
     
     delete resource;
 
