@@ -1,4 +1,4 @@
-//$Id: resource.h,v 1.10 2001/05/09 16:07:03 cactus Exp $ -*- c++ -*-
+//$Id: resource.h,v 1.11 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -24,8 +24,6 @@
 #include <gnome-xml/tree.h>
 #include <sigc++/basic_signal.h>
 
-#include "resource-util.h"
-
 namespace Guikachu
 {
     namespace Resources
@@ -42,6 +40,7 @@ namespace Guikachu
     }
 }
 
+#include "property.h"
 #include "resource-manager.h"
 
 namespace Guikachu
@@ -51,18 +50,19 @@ namespace Guikachu
 	class Resource: public SigC::Object
 	{
 	protected:
-	    string id;
+	    Resource (const string& id);
 	public:
 	    virtual ~Resource () {};
 
 	    // Resource managment functions
 	    virtual Type get_type () const = 0;
 
-	    string get_id ();
-	    void   set_id (const string& id);
-
+	    // Notification
 	    SigC::Signal0<void> changed;
 
+	    // Common properties
+	    ID id;
+	    
 	    // User interface hook
 	    virtual void show_ui () = 0;
 	    
