@@ -1,4 +1,4 @@
-//$Id: string-res.cc,v 1.5 2001/05/17 22:08:54 cactus Exp $ -*- c++ -*-
+//$Id: string-res.cc,v 1.7 2001/09/02 20:06:03 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -22,10 +22,11 @@
 
 using namespace Guikachu;
 
-Resources::String::String (const string& id_):
-    gui (0)
+Resources::String::String (const string& id):
+    Resource (id),
+    gui (0),
+    text (changed, "")
 {
-    id = id_;
 }
 
 Resources::String::~String ()
@@ -73,7 +74,7 @@ bool Resources::String::load (xmlDocPtr doc,
 
 void Resources::String::save (xmlNodePtr node) const
 {
-    xmlNewChild (node, NULL, (xmlChar*)"text", (xmlChar*)text.c_str ());
+    xmlNewChild (node, NULL, (xmlChar*)"text", (xmlChar*)string (text).c_str ());
 }
 
 void Resources::String::save_rcp (ostream &ostr) const
