@@ -1,4 +1,4 @@
-//$Id: string-res.h,v 1.3 2001/03/11 14:14:37 cactus Exp $ -*- c++ -*-
+//$Id: string-res.h,v 1.4 2001/08/18 14:23:01 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -38,13 +38,13 @@ namespace Guikachu
 	{
 	    GUI::StringWindow *gui;
 	public:
-	    String (const string& name_);
+	    String (const string& id);
 	    virtual ~String ();
 
 	    virtual Type get_type () const { return RESOURCE_STRING; };
 	    virtual void show_ui ();
 
-	    GUIKACHU_RESOURCE_PROP (text, string);
+	    Property<string> text;
 
 	private:
 	    virtual bool load (xmlDocPtr xml_doc, xmlNodePtr node);
