@@ -1,4 +1,4 @@
-//$Id: string-win.h,v 1.4 2001/04/10 16:17:28 cactus Exp $ -*- c++ -*-
+//$Id: string-win.h,v 1.5 2001/08/19 13:18:44 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -30,10 +30,6 @@ namespace Guikachu
 #include "string-res.h"
 
 #include <gtk--/window.h>
-#include <gtk--/entry.h>
-#include <gtk--/text.h>
-
-#include <glade/glade-xml.h>
 
 namespace Guikachu
 {
@@ -42,25 +38,16 @@ namespace Guikachu
 	class StringWindow: public SigC::Object
 	{
 	    Resources::String *res;
-
-	    GladeXML    *gui;
-	    Gtk::Window *window;
-	    
-	    Gtk::Entry  *id_entry;
-	    Gtk::Text   *text_entry;
+	    Gtk::Window       *window;
 
 	public:
-	    StringWindow (Guikachu::Resources::String *res);
+	    StringWindow (Resources::String *res);
 	    ~StringWindow ();
 
 	    void show ();
 	private:
 	    int delete_event_impl (GdkEventAny *e);
 	    void update ();
-	    void id_entry_cb ();
-
-	    void text_entry_cb ();
-	    bool block_text_entry_cb;
 	};
     };
 };
