@@ -1,4 +1,4 @@
-//$Id: string-list.cc,v 1.3 2001/08/10 16:10:36 cactus Exp $ -*- c++ -*-
+//$Id: string-list.cc,v 1.4 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -27,12 +27,9 @@
 
 using namespace Guikachu::GUI;
 
-StringList::StringList (get_slot_t get_slot,
-			set_slot_t set_slot,
-			changed_t& changed_sig):
+StringList::StringList (Property<value_t> &property_):
     Gtk::HBox (false, 5),
-    get_val (get_slot),
-    set_val (set_slot),
+    property (property_),	 
     update_block (false)
 {
     using namespace SigC;
@@ -88,7 +85,7 @@ StringList::StringList (get_slot_t get_slot,
     buttons->show_all ();
     add (*manage (buttons));
     
-    changed_sig.connect (slot (this, &StringList::update));
+    property.changed.connect (slot (this, &StringList::update));
     update ();
     selection_cb ();
 }
@@ -99,7 +96,7 @@ void StringList::update ()
 
     list_widget->items ().clear ();
     
-    value_t curr_val = get_val ();
+    value_t curr_val = property;
     unsigned int index = 0;
     for (value_t::const_iterator i = curr_val.begin ();
 	 i != curr_val.end (); i++, index++)
@@ -135,9 +132,9 @@ void StringList::selection_cb ()
 
 	btnRemove->set_sensitive (true);
 	btnUp->set_sensitive ((index > 0));
-	btnDown->set_sensitive ((index < (get_val ().size () - 1)));
+	btnDown->set_sensitive ((index < (property ().size () - 1)));
 
-	entry->set_text (get_val ()[index]);
+	entry->set_text (property ()[index]);
     }
 }
 
@@ -148,9 +145,9 @@ void StringList::button_remove_cb ()
     Gtk::List::SelectionList::iterator sel = list_widget->selection ().begin ();  
     unsigned int index = GPOINTER_TO_UINT ((*sel)->get_user_data ());
 
-    value_t val = get_val ();
+    value_t val = property;
     val.erase (val.begin () + index);
-    set_val (val);
+    property = val;
 
     list_widget->select_item (index);
 }
@@ -163,11 +160,11 @@ void StringList::button_up_cb ()
     unsigned int index = GPOINTER_TO_UINT ((*(sel_list.begin ()))->get_user_data ());
     g_return_if_fail (index != 0);
 
-    value_t val = get_val ();
+    value_t val = property;
     value_t::iterator curr = val.begin () + index;
     value_t::iterator prev = curr - 1;
     iter_swap (curr, prev);
-    set_val (val);
+    property = val;
 
     list_widget->select_item (index - 1);
 }
@@ -180,11 +177,11 @@ void StringList::button_down_cb ()
     unsigned int index = GPOINTER_TO_UINT ((*(sel_list.begin ()))->get_user_data ());
     g_return_if_fail (index < list_widget->items ().size () - 1);
 
-    value_t val = get_val ();
+    value_t val = property;
     value_t::iterator curr = val.begin () + index;
     value_t::iterator next = curr + 1;
     iter_swap (curr, next);
-    set_val (val);
+    property = val;
 
     list_widget->select_item (index + 1);
 }
@@ -196,9 +193,9 @@ void StringList::button_add_cb ()
     if (list_widget->selection ().size ())
 	index = GPOINTER_TO_UINT ((*(list_widget->selection ().begin ()))->get_user_data ());
     
-    value_t curr_val = get_val ();
+    value_t curr_val = property;
     curr_val.push_back (entry->get_text ());
-    set_val (curr_val);
+    property = curr_val;
 
     if (index)
 	list_widget->select_item (index);
@@ -214,10 +211,10 @@ void StringList::entry_activate_cb ()
     
     string new_text = entry->get_text ();
     unsigned int index = GPOINTER_TO_UINT ((*(list_widget->selection ().begin ()))->get_user_data ());
-    value_t val = get_val ();
+    value_t val = property;
 
     val[index] = new_text;
-    set_val (val);
+    property = val;
 
     list_widget->select_item (index);
 }
