@@ -1,4 +1,4 @@
-//$Id: widget-combo.cc,v 1.1 2001/04/14 18:01:40 cactus Exp $ -*- c++ -*-
+//$Id: widget-combo.cc,v 1.2 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-
 
 /* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
  * 
@@ -25,18 +25,15 @@
 
 using namespace Guikachu;
 
-GUI::WidgetCombo::WidgetCombo (Resources::Form *form_,
-			       Widgets::Type    type_,
-			       SigC::Slot0<string> get_slot,
-			       SigC::Slot1<void, const string&> set_slot,
-			       SigC::Signal0<void>& changed):
+GUI::WidgetCombo::WidgetCombo (Resources::Form  *form_,
+			       Widgets::Type     type_,
+			       Property<string> &property_):
     Gtk::HBox (false, 5),
     form (form_),
     button_edit (_("Edit...")),
     type (type_),
     current (""),
-    get_val (get_slot),
-    set_val (set_slot)
+    property (property_)
 {
     combo.set_value_in_list (true, true);
     combo.set_use_arrows (true);
@@ -63,7 +60,7 @@ GUI::WidgetCombo::WidgetCombo (Resources::Form *form_,
     pack_start (combo);
     pack_start (button_edit);
 
-    changed.connect (slot (this, &WidgetCombo::update));
+    property.changed.connect (slot (this, &WidgetCombo::update));
     update ();
 }
 
@@ -74,12 +71,12 @@ void GUI::WidgetCombo::add_widget (Widgets::Widget *widget)
     
     update_block = true;
 
-    Gtk::ListItem *item = new Gtk::ListItem (widget->get_id ());
+    Gtk::ListItem *item = new Gtk::ListItem (widget->id ());
     item->set_user_data (widget);
     item->show ();
     combo.get_list ()->add (*manage (item));
 
-    if (widget->get_id () == current)
+    if (widget->id () == current)
 	current_widget = widget;
     combo.get_entry ()->set_text (current);
 
@@ -106,15 +103,15 @@ void GUI::WidgetCombo::remove_widget (Widgets::Widget *widget)
     
     update_block = false;
     
-    if (widget->get_id () == current)
-        set_val ("");
+    if (widget->id () == current)
+        property = "";
 }
 
 void GUI::WidgetCombo::update ()
 {
     update_block = true;
 
-    current = get_val ();
+    current = property;
     current_widget = form->get_widget (current);
     
     combo.get_entry ()->set_text (current);
@@ -136,7 +133,7 @@ void GUI::WidgetCombo::entry_cb ()
     {
 	current = combo.get_entry ()->get_text ();
 	current_widget = form->get_widget (current);
-	set_val (current);
+	property = current;
     }
     
     if (current != "")
@@ -148,7 +145,7 @@ void GUI::WidgetCombo::entry_cb ()
 void GUI::WidgetCombo::widget_changed_cb (Widgets::Widget *widget)
 {
     if (widget == current_widget)
-	combo.get_entry ()->set_text (widget->get_id ());
+	combo.get_entry ()->set_text (widget->id);
     
     update_block = true;
 
@@ -161,7 +158,7 @@ void GUI::WidgetCombo::widget_changed_cb (Widgets::Widget *widget)
     g_return_if_fail (i != itemlist.end ());
     
     (*i)->remove ();
-    (*i)->add_label (widget->get_id ());
+    (*i)->add_label (widget->id);
     
     update_block = false;
 }
